#!/bin/sh
#@***h* GPCP_Monthly_Analysis/GPCPcdr_ECPm_Process1month.sh
#       Global Precipitation Climatology Project (GPCP)
#
# NAME
#   GPCPcdr_ECPm_Process1month.sh
#
# PURPOSE
#   This routine produces the monthly GPCP NetCDF file.
#
# DESCRIPTION
# The monthly GPCP code is made up of around 170 individual code files, which are 
# distributed among 10 modules of code plus another 6+ codes to obtain files, create 
# file listings, and perform pre- and post-processing diagnostics.
# 
# Executive Control Package - Monthly Main driver code to process a single month
# This code runs all packages for a given year/month. It checks that all data is 
# present and then calls each of the constituent parts of the processing code.
#
# In its simplest form, this code can be used to process
# all data for a single month by running 
#   GPCPcdr_ECPm_Process1month.sh YYYY MM
# 
# The function will also accept input flags that control processing.  
#
# AUTHOR
#   Robert Adler, Mathew Sapiano, Jian-Jian Wang
#   University of Maryland College Park
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
#   SUPPORT TO USERS.
#
# HISTORY
# 3/2016 Initial Version prepared for NCEI
#
#@*****

# check number if inputs
if [ $# -lt 2 ]; then
    echo "Incorrect number of inputs; need: yyyy mm"
    exit 0
elif [ $# -gt 12 ]; then
    echo "Max number of inputs (12) exceeded"
    exit 0
fi


#############################################
# set inputs parameters and processing flags

# Default flags for processing
# these are overwritten if provided as input arguments
flag_m1_GetInputFiles=1
flag_GPCPcdr_m2_METH_SSMI=1
flag_GPCPcdr_m2_Adjust_Gauge=1
flag_GPCPcdr_m2_Grid_AIRS_1month=1
flag_GPCPcdr_m2_Get_TOVS_AIRS=1
flag_GPCPcdr_m4_combMW=1
flag_GPCPcdr_m4_XOVER=1
flag_GPCPcdr_m4_corr2=1
flag_GPCPcdr_m4_fuse2=1
flag_copy_all_final=1

# set year and month
yyyy=$1
mm=$2

# get two digit year
yy=`echo $yyyy | awk '{print substr($0, 3, 2)}'`


# adjust flags based on inputs
if [ $# -ge "3" ] ; then
    flag_m1_GetInputFiles=$3
fi
if [ $# -ge "4" ] ; then
    flag_GPCPcdr_m2_METH_SSMI=$4
fi
if [ $# -ge "5" ] ; then
    flag_GPCPcdr_m2_Adjust_Gauge=$5
fi
if [ $# -ge 6 ]; then
    flag_GPCPcdr_m2_Grid_AIRS_1month=$6
fi
if [ $# -ge 7 ]; then
    flag_GPCPcdr_m2_Get_TOVS_AIRS=$7
fi
if [ $# -ge 8 ]; then
    flag_GPCPcdr_m4_combMW=$8
fi
if [ $# -ge 9 ]; then
    flag_GPCPcdr_m4_XOVER=$9
fi
if [ $# -ge 10 ]; then
    flag_GPCPcdr_m4_corr2=${10}
fi
if [ $# -ge 11 ]; then
    flag_GPCPcdr_m4_fuse2=${11}
fi
if [ $# -ge 12 ]; then
    flag_copy_all_final=${12}
fi



#############################################
# Some settings 

# read data directories from OptionsM.h
InputPATH=$(echo `grep "InputPATH" OptionsM.h` | awk -F\"  '{print $2}')
InterimPATH=$(echo `grep "InterimPATH" OptionsM.h` | awk -F\"  '{print $2}')
OutputPATH=$(echo `grep "OutputPATH" OptionsM.h` | awk -F\"  '{print $2}')
GPCCPATH=$(echo `grep "GPCCPATH" OptionsM.h` | awk -F\"  '{print $2}')


# set the satelite for SSMI/SSMIS
# From GPCP tech doc (1 August 2012, p26)
# The SSMI estimates are based on data from the F08 
# instrument from August 1987 through 1991, with the F11 
# being used for 1992 through April 1995, and the F13 
# for May 1995 through December 2008.

if [ $yyyy$mm -le 198707 ]; then
    sat="F00"
    ssmi_flag=0
    ssmis_flag=0
elif [ $yyyy$mm -le 199112 ]; then
    sat="F08"
    ssmi_flag=1
    ssmis_flag=0
elif [ $yyyy$mm -le 199505 ]; then
    sat="F11"
    ssmi_flag=1
    ssmis_flag=0
elif [ $yyyy$mm -le 200812 ]; then
    sat="F13"
    ssmi_flag=1
    ssmis_flag=0
else 
    sat="F17"
    ssmi_flag=0
    ssmis_flag=1
fi


# Depending on year, certain processing modules must be off
# override modules that are not needed for chosen yyyy/mm
# Before 1998, CORR2 is replaced by CORR_ADJ

# Earliest period - use OPI from files
if [ $yyyy -le 1985 ]; then
  flag_m1_GetInputFiles=0
  flag_GPCPcdr_m2_METH_SSMI=0
  flag_GPCPcdr_m2_Grid_AIRS_1month=0
  flag_GPCPcdr_m2_Get_TOVS_AIRS=0
  flag_GPCPcdr_m4_combMW=0
  flag_GPCPcdr_m4_XOVER=0
  flag_GPCPcdr_m4_corr2=0

# "Pre-SSMI" - uses from IR Tb histograms
elif [ $yyyy$mm -le 198707 ] || [ $yyyy$mm -eq 198712 ] ; then
  flag_m1_GetInputFiles=0
  flag_GPCPcdr_m2_METH_SSMI=0
  flag_GPCPcdr_m2_Grid_AIRS_1month=0
  flag_GPCPcdr_m2_Get_TOVS_AIRS=0
  flag_GPCPcdr_m4_combMW=0
  flag_GPCPcdr_m4_XOVER=0
fi

# don't grid AIRS data prior to 2002
if [ $yyyy -le 2002 ]; then
  flag_GPCPcdr_m2_Grid_AIRS_1month=0
fi




#############################################
# Processing Step 1. (monthly)

#    a. Get listing of files for each technique
if [ $flag_m1_GetInputFiles -eq 1 ]; then
    echo "GPCPcdr_m1_GetInputFiles $yyyy $mm $sat" 
    GPCPcdr_m1/GPCPcdr_m1_GetInputFiles.sh $yyyy $mm $sat
fi



#    b. Check input files exist for processing 
GPCPcdr_m1/GPCPcdr_m1_ChkL1files.sh $yyyy $mm






#############################################
# get all interim files
# includes Algorithm processing and precip file reformatting

# METH oceanic precipitation 2.5 and 5.0 degree
if [ $flag_GPCPcdr_m2_METH_SSMI -eq 1 ]; then

    # Process SSMI code
    if [ $ssmi_flag -eq 1 ]; then

	# run 2.5 degree hist and rain codes	echo "GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/ $yyyy $mm $sat (2.5 deg)" 
	HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/GPCPcdr_m2_SSMI_Ocean_Hist/GPCPcdr_m2_SSMI_Ocean_Hist $yyyy $mm $sat 
	GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/GPCPcdr_m2_SSMI_Ocean_Rain/GPCPcdr_m2_SSMI_Ocean_Rain $yyyy $mm $sat ${InterimPATH}

	# run 5.0 degree hist and rain codes for Day and Nit
	echo "GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/ $yyyy $mm $sat (5.0 deg)"
	HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/GPCPcdr_m2_SSMI_Ocean_Hist_5deg/GPCPcdr_m2_SSMI_Ocean_Hist_5deg $yyyy $mm $sat 
	GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/GPCPcdr_m2_SSMI_Ocean_Rain_5deg/GPCPcdr_m2_SSMI_Ocean_Rain_5deg $yyyy $mm $sat Day ${InterimPATH}
	GPCPcdr_m2/GPCPcdr_m2_SSMI_Ocean/GPCPcdr_m2_SSMI_Ocean_Rain_5deg/GPCPcdr_m2_SSMI_Ocean_Rain_5deg $yyyy $mm $sat Nit ${InterimPATH}

    # Process SSMIS code
    elif [ $ssmis_flag -eq 1 ]; then

        # run 2.5 degree hist and rain codes
        echo "GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/ $yyyy $mm $sat (2.5 deg)"
        HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/GPCPcdr_m2_SSMIS_Ocean_Hist/GPCPcdr_m2_SSMIS_Ocean_Hist $yyyy $mm $sat 
        GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/GPCPcdr_m2_SSMIS_Ocean_Rain/GPCPcdr_m2_SSMIS_Ocean_Rain $yyyy $mm $sat ${InterimPATH}

        # run 5.0 degree hist and rain codes for Day and Nit 
        echo "GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/ $yyyy $mm $sat (5.0 deg)"
        HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/GPCPcdr_m2_SSMIS_Ocean_Hist_5deg/GPCPcdr_m2_SSMIS_Ocean_Hist_5deg $yyyy $mm $sat
        GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/GPCPcdr_m2_SSMIS_Ocean_Rain_5deg/GPCPcdr_m2_SSMIS_Ocean_Rain_5deg $yyyy $mm $sat Day ${InterimPATH}
        GPCPcdr_m2/GPCPcdr_m2_SSMIS_Ocean/GPCPcdr_m2_SSMIS_Ocean_Rain_5deg/GPCPcdr_m2_SSMIS_Ocean_Rain_5deg $yyyy $mm $sat Nit ${InterimPATH}

    fi
fi



# Gauge adjustment (wind-loss correction)
# Produces
# Gauge number (gpcc_25_MMYYYY_monitoring_product_v2)
if [ $flag_GPCPcdr_m2_Adjust_Gauge -eq 1 ]; then

    # Get filename to pass into fortran code and set flag for data type
    echo "GPCPcdr_m2_Adjust_Gauge $yyyy $mm"
    if [ $yyyy -le 2013 ]; then
	GPCCfname=${GPCCPATH}full_data_v7_25.nc
	GPCCDataFlag=F
    else
	GPCCfname=${GPCCPATH}monitoring_v5_25_${yyyy}_${mm}.nc
	GPCCDataFlag=M
    fi
    # run fortran code
    HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m2/GPCPcdr_m2_Adjust_Gauge/GPCPcdr_m2_Adjust_Gauge ${yyyy} ${mm} ${GPCCfname} ${InterimPATH}Adjust_Guage/ Y ${GPCCDataFlag} 

fi


# Get Gridded version of AIRS data
# This process is slow - do not recommend doing this routinely
if [ $flag_GPCPcdr_m2_Grid_AIRS_1month -eq 1 ]; then
    echo "GPCPcdr_m2_Grid_AIRS_1month $yyyy $mm"
    GPCPcdr_m2/GPCPcdr_m2_Grid_AIRS/GPCPcdr_m2_Grid_AIRS_1month.sh $yyyy $mm 
fi



# Get AIRS and TOVS files
# Produces
# TOVS precip (tovsbin.out.YYYYMM or AIRS_HIST.YYYYMM.rav)
if [ $flag_GPCPcdr_m2_Get_TOVS_AIRS -eq 1 ] ; then

    echo "GPCPcdr_m2_Get_TOVS_AIRS $yyyy $mm"
    GPCPcdr_m2/GPCPcdr_m2_Get_AIRS_TOVS/GPCPcdr_m2_TOVS_AIRS $yyyy $mm $InputPATH $InterimPATH 

fi






#############################################
# Check all rainfall estimates exist and produce diagnostic files
# outputs number of files and summary of missing data for month (by day)






#############################################
# Precipitation Merge

# CombMW: Merge Ferarro and METH to create PMW 
# Produces:
# SSMI emission precip (cg.YYYYMM.rcfull), SSMI emission number (cg.YYYYMM.Icfull),
# SSMI scattering precip (cg.YYYYMM.rgfull), SSMI scattering number (cg.YYYYMM.Igfull),
# SSMI composite precip (cg.YYYYMM.rfix),SSMI composite number (cg.YYYYMM.Ifix),
# SSMI composite source (cg.YYYYMM.src)

if [ $flag_GPCPcdr_m4_combMW -eq 1 ]; then
    echo "GPCPcdr_m4_combMW $sat $yyyy $mm"
    GPCPcdr_m4/GPCPcdr_m4_combMW/GPCPcdr_m4_combMW ${yyyy} ${mm} ${InterimPATH}/METH_Rain/${sat}Y${yy}M${mm}_2.5deg_rain_v6 ${InputPATH} ${InterimPATH} 
fi

# XOVER: make combined PMW+TOVS data
# Produces
# SSMI/TOVS composite precip (cgt.YYYYMM.rfix)
# SSMI/TOVS composite source (cgt.YYYYMM.src)
if [ $flag_GPCPcdr_m4_XOVER -eq 1 ]; then
    echo "GPCPcdr_m4_XOVER $yyyy $mm"
    GPCPcdr_m4/GPCPcdr_m4_XOVER/GPCPcdr_m4_XOVER ${yyyy} ${mm} ${InterimPATH} ${InterimPATH}AIRS_TOVS/ GPCPcdr_m4/GPCPcdr_m4_XOVER/TOVS_Listing.txt
fi

# CORR2 and CORR_ADJ - make AGPI data
# Use CORR_ADJ before 1997, then switch to CORR2
# This is because the IR data format changed in 1997
# Produces
# GPI precip (cgt.YYYYMM.rge), GPI number (cgt.YYYYMM.Iagpi.fix)
if [ $flag_GPCPcdr_m4_corr2 -eq 1 ]; then

    if [ $yyyy -le 1996 ] ; then
        echo "GPCPcdr_m4_corr_adj $yyyy $mm"
        GPCPcdr_m4/GPCPcdr_m4_CORR_ADJ/GPCPcdr_m4_corr_adj ${yyyy} ${mm} ${InputPATH} ${InterimPATH} 

    else
        echo "GPCPcdr_m4_corr2 $yyyy $mm"
        GPCPcdr_m4/GPCPcdr_m4_CORR2/GPCPcdr_m4_corr2 ${yyyy}${mm} ${InterimPATH} ${InputPATH}mergIR_3hr_1deg/ file_listings/mergIR_3hr_1deg_${yyyy}${mm}.list 

    fi
fi

# FUSE2 - final merge of all data
# Produces
# SSMI/TOVS composite error (oc.YYYYMM.ess)
# AGPI precip (oc.YYYYMM.adge), AGPI error (oc.YYYYMM.egeo),
# Multi-satellite precip (oc.YYYYMM.s), Multi-satellite error (oc.YYYYMM.es),
# Gauge precip (oc.YYYYMM.corg), Gauge error (oc.YYYYMM.ega)
# Satellite/gauge precip (oc.YYYYMM.sg), Satellite/gauge error (oc.YYYYMM.esg)
if [ $flag_GPCPcdr_m4_fuse2 -eq 1 ]; then

    # Get filename to pass into fortran code and set flag for data type
    echo "GPCPcdr_m4_fuse2 $yyyy $mm"

    if [ $yyyy -le 2013 ]; then
        GPCCfname=${GPCCPATH}full_data_v7_25.nc
        GPCCDataFlag=F
    else
        GPCCfname=${GPCCPATH}monitoring_v5_25_${yyyy}_${mm}.nc
        GPCCDataFlag=M
    fi
    # run fortran code
    GPCPcdr_m4/GPCPcdr_m4_FUSE2/GPCPcdr_m4_fuse2 ${yyyy} ${mm} ${InputPATH} ${InterimPATH} ${GPCCfname} ${GPCCDataFlag}
fi



# Now copy all relevant final files into Output Directory
if [ $flag_copy_all_final -gt 0 ]; then
    if [ ! -d ${OutputPATH}/bin/${yyyy} ]; then
	mkdir ${OutputPATH}/bin/${yyyy}
    fi
    tmpPATH=${OutputPATH}/bin/${yyyy}/${mm}/
    if [ ! -d ${tmpPATH} ]; then
	mkdir ${tmpPATH}
    fi
    # remove any exiting files for this month
    rm ${tmpPATH}*${yyyy}${mm}*

    # Earliest period (Jan 79 to Dec 85) - use OPI from files                                                                        
    #   pop   oc.197901.adge   Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate
    #   pms   oc.197901.s      Multi-satellite precipitation
    #   pga   oc.197901.corg   Gauge precipitation
    #   psg   oc.197901.sg     Satellite/gauge precipitation
    #   eop   oc.197901.egeo   Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation random error
    #   ems   oc.197901.es     Multi-satellite precipitation random error
    #   ega   oc.197901.ega    Gauge precipitation random error
    #   esg   oc.197901.esg    Satellite/gauge precipitation random error
    #   nga   oc.197901.nga    Gauge precipitation number of gauges
    if [ $yyyy -le 1985 ]; then
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.adge ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.s ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.corg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.sg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.egeo ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.es ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ega ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.esg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.nga ${tmpPATH}

    # "Pre-SSMI" (Jan 86 to jul 87, plus dec 87)- uses from IR Tb histograms                                                                     
    #   pag   oc.198601.adge    Adjusted GOES Precipitation Index (AGPI) precipitation estimate
    #   pms   oc.198601.s       Multi-satellite precipitation
    #   pga   oc.198601.corg    Gauge precipitation
    #   psg   oc.198601.sg      Satellite/gauge precipitation
    #   ems   oc.198601.es      Multi-satellite precipitation random error
    #   ega   oc.198601.ega     Gauge precipitation random error
    #   esg   oc.198601.esg     Satellite/gauge precipitation random error
    #   eag   oc.198601.egeo    Adjusted GOES Precipitation Index (AGPI) precipitation random error
    #   nga   oc.197901.nga     Gauge precipitation number of gauges
    #   pop   opi.198601.rssfix Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate
    #   pgp   oc.198601.pgp     GOES Precipitation Index (GPI) precipitation estimate
    #   ngp   oc.198601.ngp     GOES Precipitation Index (GPI) image number
    elif [ $yyyy$mm -le 198707 ] || [ $yyyy$mm -eq 198712 ] ; then
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.adge ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.s ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.corg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.sg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.egeo ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.es ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ega ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.esg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.nga ${tmpPATH}
       cp -p ${InterimPATH}OPI_le_rssfix/opi.${yyyy}${mm}.rssfix ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ngp ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.pgp ${tmpPATH}

    # modern period (Aug 87-present, excl dec 87)
    #   pse   cg.198711.rcfull   SSM/I emission precipitation estimate
    #   nse   cg.198711.Icfull   SSM/I emission precipitation number of samples
    #   pss   cg.198711.rgfull   SSM/I scattering precipitation estimate
    #   nss   cg.198711.Igfull   SSM/I scattering precipitation number of samples
    #   psc   cg.198711.rfix     SSM/I composite precipitation estimate
    #   ssc   cg.198711.src      SSM/I composite precipitation source
    #   nsc   cg.198711.Ifix     SSM/I composite precipitation number of samples
    #   pst   cgt.198711.rfix    Merged SSMI/TOVS precipitation estimate
    #   est   oc.198711.ess      Merged SSMI/TOVS precipitation random error
    #   sst   cgt.198711.src     Merged SSMI/TOVS precipitation source
    #   ptv   cgt.198711.tovs    TOVS precipitation estimate
    #   pgp   oc.198711.pgp      GOES Precipitation Index (AGPI) precipitation estimate
    #   pag   oc.198711.adge     Adjusted GOES Precipitation Index (AGPI) precipitation estimate
    #   eag   oc.198711.egeo     Adjusted GOES Precipitation Index (AGPI) precipitation random error
    #   pms   oc.198711.s        Multi-satellite precipitation
    #   ems   oc.198711.es       Multi-satellite precipitation random error
    #   psg   oc.198711.sg       Satellite/gauge precipitation estimate
    #   esg   oc.198711.esg      Satellite/gauge precipitation random error
    #   pga   oc.198601.corg     Gauge precipitation 
    #   ega   oc.198711.ega      Gauge precipitation random error
    #   nga   oc.197901.nga      Gauge precipitation number of gauges
    #   ngp   oc.198601.ngp      GOES Precipitation Index (GPI) image number
    else 
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.rcfull ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.Icfull ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.rgfull ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.Igfull ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.rfix ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.src ${tmpPATH}
       cp -p ${InterimPATH}MWComb/cg.${yyyy}${mm}.Ifix ${tmpPATH}
       cp -p ${InterimPATH}XOVER/cgt.${yyyy}${mm}.rfix ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ess ${tmpPATH}
       cp -p ${InterimPATH}XOVER/cgt.${yyyy}${mm}.src ${tmpPATH}
       cp -p ${InterimPATH}XOVER/cgt.${yyyy}${mm}.tovs ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.pgp ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.adge ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.egeo ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.s ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.es ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.sg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.esg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.corg ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ega ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.nga ${tmpPATH}
       cp -p ${InterimPATH}FUSE2/oc.${yyyy}${mm}.ngp ${tmpPATH}
    fi

  # Write NetCDF4 output file
  # disable version check on CICS2 - avoids weird problem where
  # HDF5 header was different version to library (cause unknown)
  HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m5/GPCPcdr_m5_WriteNC/GPCPcdr_m5_WriteNC $yyyy $mm v22rB1
  HDF5_DISABLE_VERSION_CHECK=3 GPCPcdr_m5/GPCPcdr_m5_WriteNC_Interim/GPCPcdr_m5_WriteNC_Interim $yyyy $mm v22rB1
  HDF5_DISABLE_VERSION_CHECK=2 GPCPcdr_m5/GPCPcdr_m5_WriteNC/GPCPcdr_m5_WriteRevNC $yyyy $mm v02r03
fi




# write message to say processing has finished and telling user to check output
# A common fault is that the output NetCDF file is empty (happens ~10% of 
# times) and so the code that makes NetCDF file needs to be re-run
echo "-----------------------------------------------------------------"
echo "Processing finished: Please check output"
echo "Be aware that the NetCDF code often (~10% of times) does not"
echo "correctly output the file.  Check the NetCDF file for each"
echo "processed month - if the fields in the file are all zero,"
echo "you will need to re-run the last part of the code that makes"
echo "the NetCDF files.  For the command you just submitted, this is:"
echo "./GPCPcdr_ECPm_Process1month.sh ${yyyy} ${mm} 0 0 0 0 0 0 0 0 0 1"
echo "-----------------------------------------------------------------"


