#/bin/sh
# Code to get data to update GPCP (CDR and ICDR)
# Updated 11/2015 (JJ WANG)
# Need to supply at least year and month - script will then retrieve all data:
#   ./get_GPCPcdr_1month.sh 2013 02
#
# Can also supply a third variable that specifies data to get. The following
# retrieves all data
#   ./get_GPCPcdr_1month.sh 2013 02 all
#
# Other options include:
#   Data                                  Keyword
#   METH Precipitation                    meth
#   AIRS V6 Precipitation                 airs
#   GPCC Gauge Precipitation              gpcc
#   GPCC First Guess Precipitation        first
#   CPC IR data                           ir
#   Ferraro Land Precipitation            ferraro
#   RSS SSMIS FCDR Tb                     ssmis
#
# Note: only one instance of a third option may be supplied. The keyword
# is _not_ case sensitive.

yyyy=$1
mm=$2

echo "--++========================================++--"
if [ $# -lt 2 ]; then
  echo "Not enough inputs (must give at least YYY MM)"
  exit 0
elif [ $# -eq 2 ]; then
  echo "Retrieving all data for $yyyy/$mm"
  varflag='all'
elif [ $# -eq 3 ]; then
  echo "Retrieving $varflag for $yyyy/$mm"
  varflag=`echo $3 | awk '{print tolower($0)}'`
elif [ $# -gt 3 ]; then
  echo "Too many inputs!"
  exit 0
fi



InputPATH=$(echo `grep "InputPATH" ../OptionsM.h` | awk -F\"  '{print $2}')
InterimPATH=$(echo `grep "InterimPATH" ../OptionsM.h` | awk -F\"  '{print $2}')
GPCCPATH=$(echo `grep "GPCCPATH" ../OptionsM.h` | awk -F\"  '{print $2}')
GPCCnrtPATH=$(echo `grep "GPCCPATH" ../OptionsM_NRT.h` | awk -F\"  '{print $2}')

# get 2-digit year
yy=`echo $yyyy | awk '{printf "%2.2d",substr($yyyy,3,2)}'`

# set SSMI/SSMIS data
ssmi="F17"

# store pwd
cwd=`pwd`

###########################
# get data

# Get Long's histograms
if [ $varflag = 'all' ] || [ $varflag = 'meth' ] || [ $varflag = 'wilheit' ] || [ $varflag = 'gmu' ]; then
  echo "--++========================================++--"
  echo "METH rainfall data: retrieving from GMU"
  echo "These files are used in place of the RSS files for the time being"
  cd ${InterimPATH}/METH_Rain/
  wget --timeout=15 -t 1 ftp://gpcp-pspdc.gmu.edu/V6/2.5/${ssmi}Y${yy}M${mm}_2.5deg_rain_v6
  cd ${InterimPATH}/METH_Rain_5deg/
  wget --timeout=15 -t 1 ftp://gpcp-pspdc.gmu.edu/V6/5.0/${ssmi}Y${yy}M${mm}Day_5.0deg_rain_v6
  wget --timeout=15 -t 1 ftp://gpcp-pspdc.gmu.edu/V6/5.0/${ssmi}Y${yy}M${mm}Nit_5.0deg_rain_v6
fi

# Get AIRS data
if [ $varflag = 'all' ] || [ $varflag = 'airs' ] || [ $varflag = 'tovs' ]; then
  echo "--++========================================++--"
  echo "AIRS V6 data: retrieving from NASA using ftp_AIRS_V6.sh"
  echo "If you need V5 data, use ftp_AIRS_V5.sh to download separately"
  cd $cwd
  ./ftp_AIRS_V6.sh $yyyy $mm
fi

# get GPCC Gauge data
if [ $varflag = 'all' ] || [ $varflag = 'gpcc' ] || [ $varflag = 'gauge' ] || [ $varflag = 'mon' ]; then
  echo "--++========================================++--"
  echo "GPCC gauge data: retrieving from DWD"
  cd ${GPCCPATH}
  wget --timeout=15 -t 1 ftp://ftp.dwd.de/pub/data/gpcc/monitoring_v5/${yyyy}/monitoring_v5_25_${yyyy}_${mm}.nc.gz
  gunzip -f monitoring_v5_25_${yyyy}_${mm}.nc.gz
fi

# get GPCC First Guess data
if [ $varflag = 'all' ] || [ $varflag = 'gpcc' ] || [ $varflag = 'gauge' ] || [ $varflag = 'first' ]; then
  echo "--++========================================++--"
  echo "GPCC first guess data: retrieving from DWD"
  cd  ${GPCCnrtPATH}
  wget ftp://ftp.dwd.de/pub/data/gpcc/first_guess/${yyyy}/first_guess_monthly_${yyyy}_${mm}.nc.gz
  gunzip -f first_guess_monthly_${yyyy}_${mm}.nc.gz
fi

#get IR data
if [ $varflag = 'all' ] || [ $varflag = 'ir' ] || [ $varflag = 'gpi' ]; then
  echo "--++========================================++--"
  if [ ! -d "${InputPATH}/mergIR_3hr_1deg/$yyyy/" ]; then
    mkdir ${InputPATH}/mergIR_3hr_1deg/$yyyy/
  fi
  if [ ! -d "${InputPATH}/mergIR_3hr_1deg/$yyyy/$mm/" ]; then
    echo "IR file path is undefined - creating"
    mkdir ${InputPATH}/mergIR_3hr_1deg/$yyyy/$mm/
  fi
  echo "IR data: retrieving from CPC"
ftp -vin ftp.cpc.ncep.noaa.gov <<EOF
user anonymous jjwang@umd.edu
bin
lcd ${InputPATH}/mergIR_3hr_1deg/$yyyy/$mm/
cd /precip/xie/pickup/gpcp/$yyyy/$yyyy$mm/
mget *
EOF
  cd ${InputPATH}/mergIR_3hr_1deg/$yyyy/$mm/
  bunzip2 -f *
  \rm *.out
  cd $cwd
fi

# Get Ferraro files
if [ $varflag = 'all' ] || [ $varflag = 'ferraro' ]; then
  echo "--++========================================++--"
  echo "Ferraro precipitation data: retrieving from NCDC"
  echo "Note: will only retrieve files if they are newer than existing files"
  cd ${InputPATH}/Ferraro/ 
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/CFR.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/LWP.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/PF2.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/PR2.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/SSA.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/ICE.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/PF1.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/PR1.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/SNW.MON
  wget -N ftp://eclipse.ncdc.noaa.gov/pub/ssmi/monthly_ncdc/25deg/WVP.MON
  cd $cwd
fi

# Get NCDC RSS SSMI/SSMIS files from RSS Cloud service
if [ $varflag = 'all' ] || [ $varflag = 'ssmis' ] || [ $varflag = 'ssmi' ] || [ $varflag = 'rss' ]; then
  if [ ! -d "${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/" ]; then
    echo "file path is undefined - creating"
    mkdir ${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/
  fi
  if [ ! -d "${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/$yyyy/" ]; then
    echo "file path is undefined - creating"
    mkdir ${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/$yyyy/
  fi
  if [ ! -d "${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/$yyyy/$mm/" ]; then
    echo "file path is undefined - creating"
    mkdir ${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/$yyyy/$mm/
  fi

  echo "--++========================================++--"
  echo "SSMI/SSMIS data for $sat: retrieving from RSS Virginia Cloud Service"
  echo "Note: may take a while to download."
  echo "All other data has now been doanloaded - you can abort if you get bored of waiting..."
  #./get_RSS_NCDCcdr_TbV7.sh $ssmi $yyyy $mm
  cd ${InputPATH}/SSMIS_RSS_NCDCcdr_TbV7/${ssmi}/$yyyy/$mm/
# wget ftp://noaa.ncdc:ocean7.glowingglobe@va.remss.com/F17/RSS_SSMIS_FCDR_V07R00_${ssmi}_D${yyyy}${mm}.tar
# wget ftp://ftp2.remss.com/ssmis/tb/cdr/F17_bad37V/RSS_SSMIS_FCDR_V07R00_${ssmi}_D${yyyy}${mm}.tar
  wget ftp://ftp2.remss.com/ssmis/tb/cdr/F17/RSS_SSMIS_FCDR_V07R00_${ssmi}_D${yyyy}${mm}.tar
  tar -xf RSS_SSMIS_FCDR_V07R00_${ssmi}_D${yyyy}${mm}.tar
  rm -f RSS_SSMIS_FCDR_V07R00_${ssmi}_D${yyyy}${mm}.tar
fi
