C     Code to get TOVS/AIRS data
C     TOVS and AIRS must be processed separately, but the ouput 
C     files are the same format - annual binary files.
C     TOVS data are simply copied into the annual file.
C     AIRS data are gridded in the code GPCPcdr_m2_Grid_AIRS
C     In this code, gridded AIRS files are calibrated to TOVS
C     and then placed in the annual file format.
C
C     Sapiano, Aug 2014: changed TOVS read/write to have grid sizes
C                 of 360/180 instead of 144/72 (this is consistent
C                 with the output files)
      program Main_GPCPcdr_m2_TOVS_AIRS



c     ******************************************************
c     Declarations

      IMPLICIT NONE

      integer*4     iyear, imonth, iday, Ndays
      integer*4     Ninputs, strlen, strlen1, ProcFlag
      real*4        tovsdata(144,72)
      character*4   cyear
      character*3   seas
      character*2   cmonth, cday
      CHARACTER*256 InterimPATH, InputPATH, infile, outfile, histroot
      logical       ex
      integer*4     NdaysInMonth(12)
     &     / 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31/


c     ******************************************************
c     Check the correct number of inputs were given
      Ninputs = iargc()
      if ( Ninputs .NE. 4 ) then
         WRITE(*,*) 'Error in GPCPcdr_m2_Get_TOVS_AIRS:'//
     &        ' Incorrect number of input arguments (should be 3)'
         STOP
      endif

C     Get arguments and set the length of the month in hours.
      call getarg(1, cyear)
      call getarg(2, cmonth)
      call getarg(3, InputPath)
      call getarg(4, InterimPath)

c     Convert month and year to numbers
      read(cyear, '(i10)' ) iyear
      read(cmonth, '(i10)' ) imonth


c     get length of InterimPATH and InputPATH
      do strlen = 1,len_trim(InterimPath)
         if (InterimPath(strlen:strlen) .eq. ' ') then
            continue
         end if
      end do
      strlen=strlen-1

      do strlen1 = 1,len_trim(InputPath)
         if (InputPath(strlen1:strlen1) .eq. ' ') then
            continue
         end if
      end do
      strlen1=strlen1-1




c     ******************************************************
c     Setup parameters

C     Set processing flag
      ProcFlag=0

c     TOVS period: 1987/08 to 2005/04 (excluding 2004/02)
      if ((iyear .EQ. 1987 .AND. imonth .GE. 8) .OR.
     &     (iyear .GE. 1988 .AND. iyear .LE. 2004) .OR.
     &     (iyear .EQ. 2005 .AND. imonth .LE. 4)) then
         ProcFlag=1
      
c     AIRS V4 period: 2004/02 plus 2005/05 to 2007/08
      elseif ((iyear .EQ. 2005 .AND. imonth .GE. 5) .OR.
     &        (iyear .EQ. 2006) .OR.
     &        (iyear .EQ. 2007 .AND. imonth .LE. 8)) then
         ProcFlag=2

c     AIRS V5 period: 2007/09 to 2013/02
      elseif ((iyear .EQ. 2007 .AND. imonth .GE. 9) .OR.
     &        (iyear .GE. 2008 .AND. iyear .LE. 2012) .OR.
     &        (iyear .EQ. 2013 .AND. imonth .LE. 2)) then
         ProcFlag=3

c     AIRS V6 period: 2013/03 onwards
      elseif ((iyear .EQ. 2013 .AND. imonth .GE. 3) .OR.
     &        (iyear .GE. 2014)) then
         ProcFlag=4
      endif
      
c     Special case: use AIRS V4 for 2004/02
      if (iyear .EQ. 2004 .AND. imonth .EQ. 2) then
         ProcFlag=2
      endif


C     establish empty annual file if one does not already exist
C     If already exists, relevant months will be overwritten
      outfile=InterimPATH(1:strlen)//
     &        '/AIRS_TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
      inquire(file=outfile, exist=ex)
      if ( .NOT. ex ) then
         call GPCPcdr_m2_make_empty_TOVS_AIRS(outfile)
      endif 


c     Determine season and number of days in month
      Ndays=NdaysInMonth(imonth)
      if ( imonth.EQ.2 ) then 
         if ( mod(iyear,400).EQ.0 ) then
            Ndays=29
         elseif ( mod(iyear,100).EQ.0 ) then
            Ndays=28
         elseif ( mod(iyear,4).EQ.0 ) then
            Ndays=29
         endif
      endif

      if (imonth.EQ.12 .OR. imonth.EQ.1 .OR. imonth.EQ.2) then
         seas="djf"
      elseif (imonth.EQ.3 .OR. imonth.EQ.4 .OR. imonth.EQ.5) then
         seas="mam"
      elseif (imonth.EQ.6 .OR. imonth.EQ.7 .OR. imonth.EQ.8) then
         seas="jja"
      elseif (imonth.EQ.9 .OR. imonth.EQ.10 .OR. imonth.EQ.11) then
         seas="son"
      else
         seas=''
      end if





c     ******************************************************
c     TOVS
c     Copy TOVS data from original format file to new file
      if (ProcFlag .EQ. 1) then
         infile=InputPATH(1:strlen1)//
     &        '/TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
         call Read_Binary_File(infile,360,180,imonth,tovsdata)
         outfile=InterimPATH(1:strlen)//
     &        '/AIRS_TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
         call Write_binary_TOVS_AIRS(outfile,tovsdata,360,180,imonth)





c     ******************************************************
c     AIRS V4
c     Calibrate AIRS and copy into annual file
      elseif (ProcFlag .EQ. 2) then
         write (*,*) 'Processing AIRS V4'
         histroot='Ancillary/V4_hists/'

C        Do calibration of AIRS to TOVS data
         do iday=1,Ndays
            write(cday, '(I2.2)' ) iday
            infile=InputPATH(1:strlen1)//'/AIRS_V4_1DD/'//cyear//'/'
     &           //cmonth//'/AIRS.SRT.le.V4.1.'
     &           //cyear//cmonth//cday//'.avg'
            outfile=InterimPATH(1:strlen)//
     &           '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//cday
            call GPCPcdr_m2_airs2tovs (infile,outfile,seas,histroot,4)
         enddo




c        Aggregate daily data to monthly file
         infile=InterimPATH(1:strlen)//
     &     '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth
         call GPCPcdr_m2_add_month(infile, Ndays)

c        Copy data for available months into TOVS/AIRS file
         infile=InterimPATH(1:strlen)//
     &        '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//'.rav'
         outfile=InterimPATH(1:strlen)//
     &        '/AIRS_TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
         call GPCPcdr_m2_AIRS_Add(infile,outfile,cmonth)





c     ******************************************************
c     AIRS V5
c     Calibrate AIRS and copy into annual file
      elseif (ProcFlag .EQ. 3) then
         write (*,*) 'Processing AIRS V5'
         histroot='Ancillary/V5_hists/'

C        Do calibration of AIRS to TOVS data
         do iday=1,Ndays
            write(cday, '(I2.2)' ) iday
            infile=InterimPATH(1:strlen)//'/AIRS_V5_1DD/'//cyear//'/'
     &           //cmonth//'/3A_AIRS.V5L2G_1DD.'
     &           //cyear//cmonth//cday//'.avg'
            outfile=InterimPATH(1:strlen)//
     &           '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//cday
            call GPCPcdr_m2_airs2tovs (infile,outfile,seas,histroot,5)
         enddo
         
c        Aggregate daily data to monthly file
         infile=InterimPATH(1:strlen)//
     &     '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth
         call GPCPcdr_m2_add_month(infile, Ndays)

c        Copy data for available months into TOVS/AIRS file
         infile=InterimPATH(1:strlen)//
     &        '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//'.rav'
         outfile=InterimPATH(1:strlen)//
     &        '/AIRS_TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
         call GPCPcdr_m2_AIRS_Add(infile,outfile,cmonth)

c     ******************************************************
c     AIRS V6
c     Calibrate AIRS and copy into annual file
      elseif (ProcFlag .EQ. 4) then
         write (*,*) 'Processing AIRS V6'
         histroot='Ancillary/V6_hists/'

C        Do calibration of AIRS to TOVS data
         do iday=1,Ndays
            write(cday, '(I2.2)' ) iday
            infile=InterimPATH(1:strlen)//'/AIRS_V6_1DD/'//cyear//'/'
     &           //cmonth//'/3A_AIRS.V6L2G_1DD.'
     &           //cyear//cmonth//cday//'.avg'
            outfile=InterimPATH(1:strlen)//
     &           '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//cday
            call GPCPcdr_m2_airs2tovs (infile,outfile,seas,histroot,6)
         enddo

c        Aggregate daily data to monthly file
         infile=InterimPATH(1:strlen)//
     &     '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth
         call GPCPcdr_m2_add_month(infile, Ndays)

c        Copy data for available months into TOVS/AIRS file
         infile=InterimPATH(1:strlen)//
     &        '/AIRS_tmp/AIRS_HIST.'//cyear//cmonth//'.rav'
         outfile=InterimPATH(1:strlen)//
     &        '/AIRS_TOVS/monthlies.rain.'//cyear//'.am.pm.avg'
         call GPCPcdr_m2_AIRS_Add(infile,outfile,cmonth)



c     Failure option for the processing flag
      else
         write (*,*) 'Could not interpret ProcFlag:'//
     &        ' No TOVS/AIRS data for this period?'
         return
      endif


      end program Main_GPCPcdr_m2_TOVS_AIRS
