	SUBROUTINE FOV2FGC  ( flon,  flat, ift, ifp, xor, yor, w, s, 
     +			      influ, ip,   it,  iret )
C************************************************************************
C* FOV2FGC  Map an AIRS FOV to the central fine grid			*
C*									*
C* This subroutine maps one AIRS FOV to corresponding grid boxes in the	*
C* regular-CED central fine grid (FG).  The pixel value is attributed	*
C* to the box when the box is closer to the pixel than the box's	*
C* current pixel, where "close" is defined as squared elliptical	*
C* distance from pixel center.						*
C* NOTE: The grid is left-handed because y increases down.		*
C*									*
C* FOV2FGC  ( flon, flat, ift, ifp, xor, yor, w, s, influ, ip, it,	*
C*            iret )							*
C*									*
C* Input parameters:							*
C*   flon	REAL	FOV central longitude				*
C*   flat	REAL	FOV central latitude				*
C*   ift	INT1	FOV time after orbit segment start in minutes	*
C*   ifp	INT2	FOV precip					*
C*   xor	REAL	X component of FOV orientation in FG coord.	*
C*   yor	REAL	Y component of FOV orientation in FG coord.	*
C*   w		REAL	FOV width (cross-scan) in km			*
C*   s		REAL	FOV length (along-scan) in km			*
C*									*
C* Input and output parameters:						*
C*   influ	INT1*	Fine-grid elliptical distance squared, I1	*
C*			scaled by 10					*
C*   ip		INT2*	Fine-grid precip, I2 scaled by 10		*
C*   it		INT1*	Fine-grid time after orbit segment start in	*
C*			minutes, I1					*
C*									*
C* Output parameters:							*
C*   iret	INT	Return code: 0 = normal				*
C*				    -1 = stop				*
C**									*
C* Log:									*
C* G.Huffman/SSAI	 5/06	Adapt amsu_grid/fov2fgc.f; change	*
C*				AMSU->AIRS; enlarge FOV template by 2	*
C*				fine-grid boxes each direction; change	*
C*				influ thresh. from 50 to 20		*
C************************************************************************
	IMPLICIT	NONE
	INTEGER*4	nxmx, nymx, nx0, ny0,  nxa,     nxb,  nya, 
     +			nyb,  i,    ii,  j
	INTEGER*1	i_d2
	REAL*4		fx0,  fy0,  x,   y,    d2,      w_fg, s_fg, cosl
	REAL*8		xx,   xy,   yy,  xor2, xoryor2, yor2, hor2s2, 
     +			hor2w2
C
	INTEGER*4	LATEDGE, NFGFR, NX, NY
	REAL*4		RE, SZDEG
	PARAMETER	( LATEDGE = 75,
     +			  NFGFR   = 16,
     +			  NX      = 360     * NFGFR,
     +			  NY      = LATEDGE * NFGFR * 2,
     +			  RE      = 6371.,
     +			  SZDEG   = 3.1415926 * 2. * RE / 360. )
	REAL*4		flon, flat, xor, yor, w, s
	INTEGER*2	ifp,  ip    (NX, NY)
	INTEGER*1	ift,  influ (NX, NY), it (NX, NY)
	INTEGER*4	iret
C

c     Need to convert degrees to radians - SAPIANO
        REAL deg2rad
        deg2rad = 4*ATAN(1.0)/180

	iret = 0
C
C	First, check for lon=lat=0. (approximately), which essentially 
C	always marks an error in navigation.  If so, just return.
C
	IF  ( ABS ( flon ) .LE. 0.0001 .AND. 
     +	      ABS ( flat ) .LE. 0.0001 )  RETURN
C
C	Both the orientation and the fine-grid computation are in y-
C	increasing-down left-handed coordinate systems, so where we
C	use directed pairs (x,y), the negative of the y is used.   
C	  xor,yor are in FG coordinates, so xor must be scaled by
C	1/cosl to work in FG lat. boxes.
C	  W and S are converted to units of FG lat. boxes.  
C
	IF  ( flon .GE. 0 )  THEN
	    fx0 = flon * NFGFR
	  ELSE
	    fx0 = ( flon + 360. ) * NFGFR
	END IF
	fy0     = ( LATEDGE - flat ) * NFGFR
	nx0     = fx0 + 1.
	ny0     = fy0 + 1.
	cosl    = COS ( deg2rad*flat )
	nxmx    = s / SZDEG * NFGFR / cosl
	nymx    = s / SZDEG * NFGFR
	w_fg    = w / SZDEG * NFGFR
	s_fg    = s / SZDEG * NFGFR
	xor2    =  xor *  xor * ( cosl * cosl )
	xoryor2 =  xor * (-yor) * cosl * 2
	yor2    = (-yor) * (-yor)
	hor2s2  = 4. / ( xor2 + yor2 ) / ( s_fg * s_fg )
	hor2w2  = 4. / ( xor2 + yor2 ) / ( w_fg * w_fg )
C
C	Set limits and check that some of the FOV is on the grid.
C
	nxa = nx0 - nxmx / 2 - 3
	nxb = nx0 + nxmx / 2 + 3
	nya = ny0 - nymx / 2 - 3
	nyb = ny0 + nymx / 2 + 3
       	IF  ( nyb .LT. 1 .OR. nya .GT. NY )  RETURN
	IF  ( nya .LT. 1   )  nya = 1
	IF  ( nyb .GT. NY )  nyb = NY
C
C	Loop through fine-grid boxes, wrapping at the lateral grid 
C	edges, if needed, computing squared elliptical distance, and 
C	inserting pixel values if the distance is smaller than the 
C	present grid value.
C
C	The squared elliptical distance is 
C	d2 = (x'/(s/2))**2 + (y'/(w/2))**2
C	where x',y' are distances from FOV center along- and across-
C	scan direction, and d2=1 defines the nominal edge of the FOV.
C	The rotated x',y' coordinate system is defined by
C	x' = R * COS (theta-theta0)
C	y' = R * SIN (theta-theta0)
C	with R      = common radial coordinate value,
C	     theta  = angle in map x,y system,
C	     theta0 = angle from x to x', defined by xor,yor, and
C	     the origins are co-located.
C	Substitute these x',y' expressions into d2 and expand.  The
C	basic product terms are pre-computed for speed.
C
CZZZZZZZZSTRT
c	WRITE (*,*) 'fx0,fy0,nx0,ny0,nxmx,nymx,nxa,nxb,nya,nyb,xor,yor', 
c     +		    fx0,fy0,nx0,ny0,nxmx,nymx,nxa,nxb,nya,nyb,xor,yor
c	WRITE (*, *) 'x,y,d2,i_d2'
CZZZZZZZZSTOP
	DO  j = nya, nyb
	DO  i = nxa, nxb
	    IF  ( i .LT. 1 )  THEN
		ii = i + NX
	      ELSE IF  ( i .GT. NX )  THEN
		ii = i - NX
	      ELSE
		ii = i
	    END IF
	    x = ( ( FLOAT (i) - 0.5 ) - fx0 ) * cosl
	    y =   ( FLOAT (j) - 0.5 ) - fy0
	    xx =  x * x
	    xy =  x * (-y)
	    yy = (-y) * (-y)
	    d2 = ( xx * xor2 + xy * xoryor2 + yy * yor2 ) * hor2s2 +
     +		 ( xx * yor2 - xy * xoryor2 + yy * xor2 ) * hor2w2
	    i_d2 = AMIN1 ( 20., 10. * d2 )
	    IF  ( i_d2 .LT. influ (ii, j) )  THEN
		influ (ii, j) = i_d2
		ip    (ii, j) = ifp
		it    (ii, j) = ift
	    END IF
CZZZZZSTRT
c	    WRITE (*, *) x,y,d2,i_d2
CZZZZZZSTOP
	END DO
	END DO
CZZZZZSTRT
c	CALL DMPIMGF ( influ (1, 971), 'airs.influ11', ' ', .FALSE., 
c     +		       1440, 320, iret )
c	IF  ( i .GE. 1 )  STOP
CZZZZZSTOP
C
	RETURN
	END
