	SUBROUTINE READ_AIRS (airsname, ihour, MXLN, MXLT, precip, time,
     +			      alat, alon, iscind, ipxind, igran, iqflag)
C
C***********************************************************************
C* READ_AIRS	Reads data from the daily AIRS L2G HDFs.	       *
C*								       *
C* Called by:	<...>						       *
C*   								       *
C* Calls:	GETL2GFD, GETL2GDD				       *
C*  								       *
C* READ_AIRS opens and extracts selcted data from the daily AIRS L2G   *
C* HDFs for input into the backward gridder.  The data is of the form  *
C* (1440,720), where each hour has a unique gridbox value for each     *
C* 0.25-degree box.						       *
C*  								       *
C* Input Parameters:						       *
C*								       *
C*  airsname 	CHAR	AIRS L2G file name			       *
C*  ihour 	INT	Hour of data to be read (1-24)		       *
C*  MXLN        INT     X-dimension of output arrays (1440)            *
C*  MXLT        INT     Y-dimension of output arrays (720)             *
C* 								       *
C* Output Parameters:						       *
C*								       *
C*  precip 	REAL	AIRS precipitation data (100.*mm/hr)	       *
C*  time 	REAL	AIRS data observation times (seconds since 00Z *
C*			January 1, 1993)			       *
C*  alat 	REAL	AIRS observation latitudes		       *
C*  alon 	REAL	AIRS observation longitudes		       *
C*  iscind 	BYTE	AIRS scan index (0-44)			       *
C*  ipxind 	BYTE	AIRS pixel index (0-29)			       *
C*  igran 	BYTE	AIRS granule number (0-240)		       *
C*  iqflag 	INT	AIRS quality flag			       *
C* 								       *
C**								       *
C* Log:								       *
C* D.Bolvin/SSAI	02/07	First Version			       *
C* E.Nelkin/SSAI	03/07	Pass in MXLN, MXLT                     *
C* E.Nelkin/SSAI	03/07	Convert precip from mm/day to 100*mm/hr*
C* E.Nelkin/SSAI	08/12	LINUX Version			       *
C***********************************************************************
C
	IMPLICIT	NONE
C
C***********************************************************************
C	Include header file for FORTRAN HDF parameter definitions.
C
C	INCLUDE		"/usr/apps/32/hdf4.1r1/include/hdf.inc"
C	INCLUDE		"/usr/local/hdf4/include/hdf.inc"
C       Changed by Sapiano
C	INCLUDE		"/usr/local/hdf-4.2.6/include/hdf.inc"
	INCLUDE		"hdf.inc"
C
C***********************************************************************
C	Declaration of internal subroutine variables.
C
	INTEGER*4	isd_id
        INTEGER*4	iindex, istatus
	INTEGER*4	sfstart, sfend, heprnt
        INTEGER*4       i, j
C
	INTEGER*4	ihour
        INTEGER*4       MXLN, MXLT
C
	INTEGER*1	iscind(MXLN,MXLT), ipxind(MXLN,MXLT),
     +			igran(MXLN,MXLT)
C
	INTEGER*2	iqflag(MXLN,MXLT)
C
	REAL*4		precip(MXLN,MXLT), alat(MXLN,MXLT),
     +			alon(MXLN,MXLT)
        REAL*8		time(MXLN,MXLT)
C
	CHARACTER*256	airsname
C
C***********************************************************************
C	Check that the hour index is within range.
C
	IF  ((ihour .LT. 1) .OR. (ihour .GT. 24)) THEN
	    WRITE (*,*) 'ERROR: INPUT HOUR NUMBER MUST BE IN THE ',
     +			'RANGE 1-24; TERMINATING EXECUTION; ',
     +			'SUBROUTINE READ_AIRS'
     	    STOP
	END IF
C
C***********************************************************************
C	Open the AIRS L2G HDF file.
C
	isd_id = sfstart (airsname, DFACC_READ)
C
	IF  (isd_id .EQ. FAIL) THEN
	    WRITE (*,*) 'ERROR: UNABLE TO OPEN INPUT AIRS L2G FILE ',
     +			 airsname
	    istatus = heprnt (0)
	    STOP
	END IF
C
C***********************************************************************
C	Get the precipitation data, and convert from mm/day to
C       100.*mm/hr.
C
	iindex = 11
C
	CALL GETL2GFD (isd_id, iindex, ihour, precip)
        DO j = 1, MXLT
        DO i = 1, MXLN
           IF ( precip(i,j) .GE. 0.) THEN
              precip(i,j) = 100. * precip(i,j)/24.
           ELSE
              precip(i,j) = 10. * precip(i,j)/24.
           END IF
        END DO
        END DO
C
C***********************************************************************
C	Get the time data.
C
	iindex = 5
C
	CALL GETL2GDD (isd_id, iindex, ihour, time)
C
C***********************************************************************
C	Get the latitude data.
C
	iindex = 3
C
	CALL GETL2GFD (isd_id, iindex, ihour, alat)
C
C***********************************************************************
C	Get the longitude data.
C
	iindex = 4
C
	CALL GETL2GFD (isd_id, iindex, ihour, alon)
C
C***********************************************************************
C	Get the scan indices.
C
	iindex = 14
C
	CALL GETL2GBD (isd_id, iindex, ihour, iscind)
C
C***********************************************************************
C	Get the pixel indices.
C
	iindex = 15
C
	CALL GETL2GBD (isd_id, iindex, ihour, ipxind)
C
C***********************************************************************
C	Get the granule numbers.  Note that the range of these values is
C	0-240, but FORTRAN cannot handle unsigned byte.  So, if a 
C	non-fill or non-missing number is encountered, add the negative
C	value to 256 to get the intended granule number.
C
	iindex = 6
C
	CALL GETL2GBD (isd_id, iindex, ihour, igran)
C
C***********************************************************************
C	Get the quality flags.
C
	iindex = 13
C
	CALL GETL2GID (isd_id, iindex, ihour, iqflag)
C
C***********************************************************************
C	Close the AIRS L2G HDF file.
C
	istatus = sfend (isd_id)
C
	IF  (istatus .EQ. FAIL) THEN
	    WRITE (*,*) 'ERROR: UNABLE TO CLOSE INPUT AIRS L2G FILE ',
     +			 airsname
	    istatus = heprnt (0)
	    STOP
	END IF
C
	RETURN
	END
