	SUBROUTINE SAMERR  ( FAC,   LN,   LT, ECONST, ACONST,
     +			     field, N_IN, r,  p, src, e, iret )
C************************************************************************
C* SAMERR  Estimate sampling error for rainfall				*
C*									*
C* Estimate sampling error for the field selected; different parts of	*
C* the field can have different constants (up to 3 sets at present).	*
C*									*
C* The sampling error formula (Huffman, 1997) is			*
C*    var(month) = (r**2)*H/(f*Na*I)				    (1)	*
C* where r is rainfall, H is a near-const. depending on the histogram	*
C* shape, f is the fractional occurence of precip, Na is a measure of	*
C* the number of samples, and I is a near-const. factor to adjust Na to	*
C* the approx. # of independent samples.  Due to flakiness in estimates	*
C* of f, the conditional rainrate (r/f) is parameterized from a study	*
C* with GSCAT2:								*
C*    r/f = 1 + 10 * SQRT ( r ) 				    (2)	*
C* with r in mm/hr (originally 3 and 2.4).  Also, the remaining r in	*
C* (1) must be estimated from the box-average, so we choose to boost it	*
C* by a nominal (constant) estimate of Std.Dev(r) near r=0 (denoted by	*
C* S).  The actual form of the equation becomes:			*
C*    var(month) = (r+S)*(H/I)/Na*(1+10*SQRT(r))			*
C* and S and H/I are set empirically from studying typical errors.	*
C*									*
C* When there are different sources and consequently different error	*
C* constants), say, for land and water, the constants in mixed regions	*
C* are weighted according to src.  ss=RMISS implies no input data.	*
C* The various factors of FAC take care of r being in some units	*
C* besides mm/hr.							*
C*									*
C* The error of a combination is					*
C*    E12**2 = e1**2 * wt1**2 + e2**2 * wt2**2				*
C* but the combined SSM/I and SSM/I&TOVS fields should just have values	*
C* intermediate between the values of the individual fields, so the	*
C* equation used is							*
C*    E12**2 = e1**2 * wt1 + e2**2 * wt2				*
C*									*
C* SAMERR  ( FAC, LN, LT, ECONST, ACONST, field, N_IN, r, p, src, e,	*
C*           iret )							*
C*									*
C* Input parameters:							*
C*   FAC	REAL	Factor to scale from mm/hr to units of r	*
C*   LN		INT	X size						*
C*   LT		INT	Y size						*
C*   ECONST	REAL*	Multiplicative const., either for only field or	*
C*			for SSM/I scattering, SSM/I emission, MSU,	*
C*			TOVS, AGPI, gauge, computer (same units as p)	*
C*   ACONST	REAL*	Additive const., either for only field or as	*
C*			above (same units as r)				*
C*   field	CHAR*	Field name: 'ssmi' SSM/I - single or combo.	*
C*				    'ssto' SSM/I single/combo & TOVS	*
C*				    'tovs' TOVS				*
C*				    'msu ' MSU				*
C*				    'msto' MSU & TOVS			*
C*			'agpi','gaug','comp')				*
C*   N_IN	INT	Number of input fields (1 or 2)			*
C*   r		REAL*	Rainfall (size LN,LT)				*
C*   p		REAL*	Population (size LN,LT)				*
C*   src	REAL*   Source array (size LN,LT)			* 
C*			0-1 SSM/I fields 1 to 2				*
C*			2-3 SSM/I fields 1 to 2 and TOVS		*
C*			4   TOVS					*
C*			5   MSU						*
C*			6   MSU and TOVS				*
C*									*
C* Output parameters:							*
C*   e		REAL*	Sampling error (same units as r; size LN,LT)	*
C*   iret	INT	Return code: 0 = normal				*
C*				    -1 = unknown N_IN/field combo	*
C**									*
C* Log:									*
C* G.Huffman/SSAI	 3/96	Pull out of FUSEE.F			*
C* G.Huffman/SSAI	 3/96	Boost clos mult. to .75			*
C* G.Huffman/SSAI	10/97	Add third field, TOVS, MSU; correct	*
C*				conditional rainrate doc.		*
C* G.Huffman/SSAI	11/97	Re-work third field concept		*
C* G.Huffman/SSAI	 4/98	Make local arrays size 720,360		*
C* D.Bolvin/SSAI	11/08	Explicitly type variables		*
C************************************************************************
	IMPLICIT	NONE
C
	INTEGER*4	MXLN, MXLT
	REAL*4		RMISS
	PARAMETER	( MXLN  = 720,
     +			  MXLT  = 360,
     +			  RMISS = -99999. )
C
	INTEGER*4	i, j, ihaveg (MXLN, MXLT)
	REAL*4		srcs, gsouth, gnorth, clos
	CHARACTER*4	lc_fld
C
C	Args are (ln,lt).
C
	REAL*4		FAC, ECONST (7), ACONST (7),
     +			r (LN, LT),      p (LN, LT), src (LN, LT),
     +			e (LN, LT)
	INTEGER*4	LN, LT, N_IN,    iret
	CHARACTER*(*)	field
C

c       Need to convert degrees to radians - SAPIANO
        REAL deg2rad
        deg2rad = 4*ATAN(1.0)/180

	iret = 0
	IF  ( LN .LE. MXLN .AND. LT .LE. MXLT )  THEN
	    iret = 0
	  ELSE
	    WRITE (*, 5) LN, LT, MXLN, MXLT
    5	    FORMAT ( 'Error: Dimensions LN,LT = (', I3, ',', I3, 
     +              ') exceed max = (' I3, ',', I3, ') in ERREST' )
	    STOP
	END IF

c       This next line ensured that field was lowercase, but was 
c       unnecessary since field can be upper or lower (but not mixed)
c	CALL ST_UCLC ( field (1:4), lc_fld, iret )
	lc_fld=field(1:4)


C
C	Compute error for single-source SSM/I, TOVS, or MSU.
C
	IF  ( ( lc_fld .EQ. 'ssmi' .OR. lc_fld .EQ. 'tovs' .OR.
     +	        lc_fld .EQ. 'msu ' ) .AND. N_IN .EQ. 1 )  THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( p (i, j) .LE. 0. .OR. r (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE
		    e (i, j) = ( ( ACONST (1) + r (i, j) ) * 
     +				 ECONST (1) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) ** .5 ) /
     +				 p (i, j) ) ** .5
		END IF
	    END DO
	    END DO
C
C	  Compute error for two-source SSM/I.
C
	  ELSE IF  ( ( lc_fld .EQ. 'ssmi' ) .AND. N_IN .EQ. 2 )
     +								THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( p   (i, j) .LE. 0. .OR. r (i, j) .LT. 0. .OR.
     +		      src (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE
		    srcs     = src (i, j)
		    e (i, j) = ( ( ( ACONST (1) + r (i, j) ) * 
     +				   ECONST (1) * ( 1. - srcs ) +
     +				   ( ACONST (2) + r (i, j) ) * 
     +				   ECONST (2) * srcs ) *
     +				 ( 1. * FAC +  
     +				   10. * ( FAC * r (i, j) ) ** .5 ) / 
     +				 p (i, j) ) ** .5
		END IF
	    END DO
	    END DO
C
C	  Compute error for one- or two-source SSM/I (OR MSU) plus TOVS 
C	  as coded in src).  The weight of SSM/I (OR MSU) with TOVS is 
C	  .5 .  The order of tests is "missing", SSM/I, MSU, SSM/I with 
C	  TOVS, MSU with TOVS, TOVS.
C
	  ELSE IF  ( ( lc_fld .EQ. 'ssto' .OR. 
     +		       lc_fld .EQ. 'msto' ) .AND. 
     +		     ( N_IN .EQ. 2 .OR. N_IN .EQ. 3 ) )  THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( p   (i, j) .LE. 0. .OR. r (i, j) .LT. 0. .OR.
     +		      src (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE IF  ( src (i, j) .LE. 1. )  THEN
		    srcs     = src (i, j)
		    e (i, j) = ( ( ( ACONST (1) + r (i, j) ) * 
     +				   ECONST (1) * ( 1. - srcs ) +
     +				   ( ACONST (2) + r (i, j) ) * 
     +				   ECONST (2) * srcs ) *
     +				 ( 1. * FAC +  
     +				   10. * ( FAC * r (i, j) ) ** .5 ) / 
     +				 p (i, j) ) ** .5
		  ELSE IF  ( src (i, j) .EQ. 5. )  THEN
		    e (i, j) = ( ( ACONST (3) + r (i, j) ) * 
     +				 ECONST (3) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) ** .5 ) /
     +				 p (i, j) ) ** .5
		  ELSE IF  ( src (i, j) .LE. 3. )  THEN
		    srcs     = src (i, j) - 2.
		    e (i, j) = ( ( ( ( ACONST (1) + r (i, j) ) * 
     +				     ECONST (1) * ( 1. - srcs ) +
     +				     ( ACONST (2) + r (i, j) ) * 
     +				     ECONST (2) * srcs )  / p (i, j) +
     +				   ( ACONST (4) + r (i, j) ) * 
     +				   ECONST (4) ) *
     +				 ( 1. * FAC +  
     +				   10. * ( FAC * r (i, j) ) ** .5 ) * 
     +				 .5 ) ** .5
		  ELSE IF  ( src (i, j) .EQ. 6. )  THEN
		    e (i, j) = ( ( ( ACONST (3) + r (i, j) ) * 
     +				   ECONST (3)  / p (i, j) +
     +				 ( ACONST (4) + r (i, j) ) * 
     +				 ECONST(4) ) *
     +				 ( 1. * FAC +  
     +				   10. * ( FAC * r (i, j) ) ** .5 ) * 
     +				 .5 ) ** .5
		  ELSE IF  ( src (i, j) .EQ. 4. )  THEN
		    e (i, j) = ( ( ACONST (4) + r (i, j) ) * 
     +				 ECONST (4) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) ** .5 ) /
     +				 p (i, j) ) ** .5
		  ELSE
		    WRITE (*, *) 'Error: don''t recognize value for',
     +				 ' i,j,src =', i, j, src (i, j)
		    e (i, j) = RMISS
		END IF
	    END DO
	    END DO
C
C	  Compute AGPI error with 1 field.  AGPI p is in number of 
C	  of images, and the number of independent samples in a grid
C	  box decreases as the area (proportional to COS(lat)) away 
C	  from the equator due to the convergence of lat. lines.
C	  Notes on deficiencies in the present scheme:
C	  1. Eagpi should depend on the number of SSM/I samples as well.
C	  2. Low-orbit agpi should be worse than for geo-orbit due to an
C	     inferior adjustment scheme.
C
	  ELSE IF  ( ( field (1:4) .EQ. 'agpi' .OR. 
     +		       field (1:4) .EQ. 'AGPI' ) .AND. N_IN .EQ. 1 )
     +								THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( p (i, j) .LE. 0. .OR. r (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE
		    e (i, j) = ( ( ACONST (1) + r (i, j) ) * 
     +				 ECONST (1) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) ** .5 ) / 
     +				 ( p (i, j) * 
     +				   SIN (deg2rad* (j-.5)*180./LT ) ) ) ** .5
		END IF
	    END DO
	    END DO
C
C	  Compute gauge error with one field.  Gauge p is in number of
C	  gauges in the box, but due to the analysis technique the "true"
C	  number of gauges should reflect the presence of gauges in 
C	  surrounding boxes.  This influence is crudely accounted for
C	  by using ( gaugen + clos / 4 ) as the number of gauges, where
C	  clos is the number of surrounding boxes with at least one
C	  gauge.  Bias error (due to using the Legates climatological
C	  correction) is *not* handled here.  Start by finding clos; 
C	  all boxes are neighbors at the poles.
C
	  ELSE IF  ( ( field (1:4) .EQ. 'gaug' .OR. 
     +		       field (1:4) .EQ. 'GAUG' ) .AND. N_IN .EQ. 1 )
     +								THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( p (i, j) .EQ. 0. )  THEN
		    ihaveg (i, j) = 0
		  ELSE
		    ihaveg (i, j) = 1
		END IF
	    END DO
	    END DO
C
	    gnorth = 0.
	    gsouth = 0.
	    DO  i = 1, LN
		gnorth = gnorth + ihaveg (i, 1 )
		gsouth = gsouth + ihaveg (i, LT)
	    END DO
C
C	    Check how many neighboring boxes have at least one gauge.
C	    Boxes on the lateral boundaries are neighbors to the 
C	    opposite side and the poles use gnorth and gsouth.
C
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( j .EQ. 1 )  THEN
		    IF  ( i .EQ. 1 )  THEN
			clos = ihaveg (LN, 1) + ihaveg (2, 1) +
     +			       ihaveg (LN, 2) + ihaveg (2, 2) +
     +			       gnorth         + ihaveg (1, 2)
		      ELSE IF  ( i .EQ. LN )  THEN
			clos = ihaveg (LN-1, 1) + ihaveg (1,  1) +
     +			       ihaveg (LN-1, 2) + ihaveg (1,  2) +
     +			       gnorth           + ihaveg (LN, 2)
		      ELSE
			clos = ihaveg (i-1, 1) + ihaveg (i+1, 1) +
     +			       ihaveg (i-1, 2) + ihaveg (i+1, 2) +
     +			       gnorth          + ihaveg (i,   2)
		    END IF
		  ELSE IF  ( j .EQ. LT )  THEN
		    IF  ( i .EQ. 1 )  THEN
			clos = ihaveg (LN, LT-1) + ihaveg (2,LT-1) +
     +			       ihaveg (LN, LT  ) + ihaveg (2,LT  ) +
     +			       ihaveg (1,  LT-1) + gsouth
		      ELSE IF  ( i .EQ. LN )  THEN
			clos = ihaveg (LN-1,LT-1) + ihaveg (1,LT-1)+
     +			       ihaveg (LN-1,LT  ) + ihaveg (1,LT  )+
     +			       ihaveg (LN,  LT-1) + gsouth
		      ELSE
			clos = ihaveg (i-1,LT-1) +ihaveg (i+1,LT-1)+
     +			       ihaveg (i-1,LT  ) +ihaveg (i+1,LT  )+
     +			       ihaveg (i,  LT-1) +gsouth
		    END IF
		  ELSE IF  ( i .EQ. 1 )  THEN
		    clos = ihaveg (LN, j-1) + ihaveg (2, j-1) +
     +			   ihaveg (LN, j  ) + ihaveg (2, j  ) +
     +			   ihaveg (LN, j+1) + ihaveg (2, j+1) +
     +			   ihaveg (1,  j-1) + ihaveg (1, j+1)
		  ELSE IF  ( i .EQ. LN )  THEN
		    clos = ihaveg (LN-1, j-1) + ihaveg (1,  j-1) +
     +			   ihaveg (LN-1, j  ) + ihaveg (1,  j  ) +
     +			   ihaveg (LN-1, j+1) + ihaveg (1,  j+1) +
     +			   ihaveg (LN,   j-1) + ihaveg (LN, j+1)
		  ELSE
		    clos = ihaveg (i-1, j-1) + ihaveg (i+1, j-1) +
     +			   ihaveg (i-1, j  ) + ihaveg (i+1, j  ) +
     +			   ihaveg (i-1, j+1) + ihaveg (i+1, j+1) +
     +			   ihaveg (i,   j-1) + ihaveg (i,   j+1)
		END IF
C
C		Set gauge quality; missing if no estimate, or no gauges
C		in the box or nearby.
C
		IF  ( ( p (i, j) + clos * .125 ) .LE. 0. .OR.
     +		      r (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE
		    e (i, j) = ( ( ACONST (1) + r (i, j) ) * 
     +				 ECONST (1) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) ** .5 ) /
     +				 ( p (i, j) + clos * .125 ) ) ** .5
		END IF
	    END DO
	    END DO
C
C	  Compute model error with one field.  p is not available, but 
C	  coverage should be complete.
C
	  ELSE IF  ( ( field (1:4) .EQ. 'comp' .OR. 
     +		       field (1:4) .EQ. 'COMP' ) .AND. N_IN .EQ. 1 )  THEN
	    DO  j = 1, LT
	    DO  i = 1, LN
		IF  ( r (i, j) .LT. 0. )  THEN
		    e (i, j) = RMISS
		  ELSE
		    e (i, j) = ( ( ACONST (1) + r (i, j) ) * 
     +				 ECONST (1) * 
     +				 ( 1. * FAC + 
     +				   10. * ( FAC * r (i, j) ) **.5 ) /
     +				 1. ) ** .5
		END IF
	    END DO
	    END DO
C
C	  Oops - got to the bottom without hitting a known case.
C
	  ELSE
	    WRITE (*, *) 'Error: unknown combination of N_IN, field =',
     +			 N_IN, ', ', field
	    iret = -1
	END IF
C
	RETURN
	END
