/******* disk.c ***********************************
*
* These functions do disk file I/O in C for FORTRAN use.
*
* NOTE: Use of "int" might at some point conflict with
* INTEGER*4 declared in the FORTRAN calling programs.
* G.Huffman 2/02
*
* Log:
* G.Huffman/USRA  9/91	Adapted tape.c (by Y.Cai)
* G.Huffman/USRA  7/92	Documentation
* G.Huffman/USRA  3/93  Change strcpy to strncpy to
*                       prevent overflows
* D.Bolvin/SSAI   4/96	Add initrw_disk for read/write
*			access
* D.Bolvin/SSAI   3/04	Unified Bolvin/Huffman 
*			versions of disk.c
***************************************************/

#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <fcntl.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>


/******** init_disk ********************************
*
* This function opens the disk file named for reading.
* Equivalent to init_tape.
*
* Input:
*   file	char	File name
*	
* Return:	int	>0 = unit number
*			<0 = -errno (Unix error code)
****************************************************/

int init_disk_ ( file )
char *file;
{

char name [256];
int iunit;
strncpy ( name, file, 256 );
strtok  ( name, " " );
iunit = open ( name, O_RDONLY );
if  ( iunit < 0 )
    return -errno;
  else
    return iunit;

}/* end of init_disk */


/******** initw_disk *******************************
*
* This function opens the disk file named for writing.
*
* Input:
*   file	char	File name
*	
* Return:	int	>0 = unit number
*			<0 = -errno (Unix error code)
* Log:
* G.Huffman/USRA  1/92	Adapt init_disk
****************************************************/

int initw_disk_ ( file )
char *file;
{

char name [256];
int iunit;
strncpy ( name, file, 256 );
strtok ( name, " " );
iunit = open ( name, O_WRONLY | O_CREAT | O_TRUNC );
if  ( iunit < 0 )
    return -errno;
  else
    fchmod ( iunit, 00666 ); /* read/write for all classes */
                             /* default is read for group  */
    return iunit;

}/* end of initw_disk */


/******** inita_disk *******************************
*
* This function opens the disk file named for appended
* writing.
*
* Input:
*   file	char	File name
*	
* Return:	int	>0 = unit number
*			<0 = -errno (Unix error code)
* Log:
* G.Huffman/USRA  6/92	Adapt initw_disk
****************************************************/

int inita_disk_ ( file )
char *file;
{

char name [256];
int iunit;
strncpy ( name, file, 256 );
strtok  ( name, " " );
iunit = open ( name, O_WRONLY | O_CREAT | O_APPEND );
if  ( iunit < 0 )
    return -errno;
  else
    fchmod ( iunit, 00666 ); /* read/write for all classes */
			     /* default is read for group  */
    return iunit;

}/* end of inita_disk */


/************ read_disk *******************************
*
* This function reads the specified number of bytes from
* the disk file.  Equivalent to read_tape.
*
* Input:
*   iunit	*int	Unit number
*   buff	*char	Output buffer
*   size	*int	Expected output size (bytes) 
*
* Return:	int	>0 = number of bytes read
*			<0 = -errno (Unix error code)
* Log:
* G.Huffman/USRA  7/92  Add -errno return
******************************************************/	

int read_disk_ ( iunit, buff, size )
int *iunit, *size;
char *buff;
{

int n;
n = read ( *iunit, buff, *size );
if  ( n == -1 )  n = -errno;
return ( n );

}/* end of read_disk */


/************ write_disk *****************************
*
* This function writes the specified number of bytes to
* the disk file.
*
* Input:
*   iunit	*int	Unit number
*   buff	*char	Input buffer
*   size	*int	Expected input size (bytes) 
*
*Return:	int	>0 = number of bytes written
*			<0 = -errno (Unix error code)
* Log:
* G.Huffman/USRA  7/92	Add -errno return
******************************************************/	

int write_disk_ ( iunit, buff, size )
int *iunit, *size;
char *buff;
{

int n;
n = write ( *iunit, buff, *size );
if  ( n == -1 )  n = -errno;
return ( n );

} /* end of write */


/************ exit_disk *****************************
*
* This function closes the disk file.
*
* Input:
*   iunit	*int	Unit number
*
* Return:	int	1 = normal
*****************************************************/

int exit_disk_ ( iunit )
int *iunit;
{

close ( *iunit );
return 1;

} /* end of exit_disk */


/******** initrw_disk ********************************
*
* This function opens the disk file named for 
* simultaneous reading and writing.
*
* Input:
*   file	char	File name
*   length	int	File name length
*	
* Return:	int	>0 = unit number
*			<0 = -errno (Unix error code)
****************************************************/

int initrw_disk_ ( file, length )
char *file;
int *length;
{

char name [256];
int iunit;
strncpy ( name, file, *length );
strtok ( name, " " );
iunit = open ( name, O_RDWR );
if  ( iunit < 0 )
    return -errno;
  else
    fchmod ( iunit, 00666 ); /* read/write for all classes */
                             /* default is read for group  */  
    return iunit;

}/* end of initrw_disk */


/************ rew_unit *****************************
*
* This function moves the file pointer to the
* beginning of the file.
*
* Input:
*   file	char	File name
*
* Return:	int	0 = normal
*****************************************************/

int rew_unit_ ( filedes )
int *filedes;
{

int iret;

iret = lseek ( *filedes, 0, SEEK_SET );

return iret;

} /* end of rew_unit */
