	SUBROUTINE FILLSM  ( arrin, LN, LT, MXLN, LTSKP, npass, arrout, 
     +			     iret )
C************************************************************************
C* FILLSM  Fill holes with a 3x3 smoother for a 2-D real array		*
C*									*
C* Fill holes in a LNxLT field by repetitively applying a 3x3 smoother	*
C* at the missing points (flagged with the "R*4 missing value",		*
C* -99999.).  The north and south boundaries are filled	with "missing",	*
C* while the east and west are periodic.  Optionally, only a central	*
C* band (size LT-2*LTSKP) is processed.  If the number of passes,	*
C* npass, is known, the smoother is applied that many times; otherwise	*
C* npass is 5 times the number of passes needed to first fill  the	*
C* holes.  In the smoother, missing values simply give more weight to	*
C* the good values contributing to a point.				*
C*									*
C* FILLSM  ( arrin, LN, LT, MXLN, LTSKP, npass, arrout, iret )		*
C*									*
C* Input parameters:							*
C*   arrin	REAL*	Input data (data size LN,LT; physical size	*
C*			MXLN,LT+)					*
C*   LN		INT	Data X size					*
C*   LT		INT	Data Y size					*
C*   MXLN	INT	Array X size (don't need array Y as long as	*
C*			the data start at the "top" of the array)	*
C*   LTSKP	INT	Number of rows to skip in processing		*
C*									*
C* Input and output parameters:						*
C*   npass	INT	Number of smoother passes (0 is legitimate); 	*
C*			-1 = calculate and return number		*
C*									*
C* Output parameters:							*
C*   arrout	REAL*	Output smoothed data (data size LN,LT; physical	*
C*			size MXLN,LT+)					*
C*   iret	INT	Return code: 0 = normal				*
C*				    -1 = ismth out of bounds or even	*
C*				    -2 = no data in input array at all	*
C**									*
C* Log:									*
C* G.Huffman/USRA	 2/93	Adapt SMOOTH.F				*
C* G.Huffman/SSAI	11/94	Make missing -99999.			*
C* G.Huffman/SSAI	 4/98	Set MXX,MXY = 720,360; make RMISS	*
C*				local; add MXLN				*
C* G.Huffman/SSAI	 3/00	Check for "no data in input"; write msg	*
C*				on return error 1			*
C* G.Huffman/SSAI	 7/00	Increase npass 3->5*nfill (smoothness)	*
C* G.Huffman/SSAI	 9/00	Documentation				*
C* G.Huffman/SSAI	 2/04	Decl. indices before array decl.	*
C* G.Huffman/SSAI	 3/12	Additional doc. on first pass		*
C************************************************************************
	IMPLICIT	NONE
C
C	Args are (ln,lt).
C
	INTEGER*4	MXSM, MS_2, MXX, MXY
	REAL*4		RMISS
	PARAMETER	( MXSM = 3,
     +			  MS_2 = MXSM / 2,
     +			  MXX  = 720,
     +			  MXY  = 360,
     +			  RMISS = -99999. )
C
	INTEGER*4	LN, LT, MXLN,     LTSKP, npass, iret
	REAL*4		arrin (MXLN, LT), arrout (MXLN, LT)
C
	REAL*4		wt, xwt, smth  (MXSM, MXSM),
     +			aug   (MXX + 2 * MS_2, MXY + 2* MS_2, 2),
     +			augwt (MXX + 2 * MS_2, MXY + 2* MS_2)
	INTEGER*4	i,  ii, j, jj, k, m1, m2, ismth, is_2, nfill, n
	LOGICAL*1	done
	DATA		ismth, smth / 3, 9*1. /
C
C	Check that ismth is odd and in bounds.
C
	IF  ( ismth .LT. 3 .OR. MOD ( ismth, 2 ) .NE. 1 .OR.
     +	      ismth .GT. MXSM )  THEN
	    WRITE (*, *) 'Error: smoothing routine found ismth (=', 
     +			 ismth, ') <3, even, or >MXSM (=', MXSM, ').'
	    iret = -1
	    RETURN
	END IF
C
C	If there's no data in the input array reflect the input array
C	into the output array with an error.
C
	DO  j = 1, LT
	DO  i = 1, LN
	    IF  ( arrin (i, j) .NE. RMISS )  GO TO 10
	END DO
	END DO
	    DO  j = 1, LT
	    DO  i = 1, LN
		arrout (i, j) = arrin (i, j)
	    END DO
	    END DO
	    WRITE (*, *) 'Error: fill-smooth routine found no data.'
	    iret = -2
	    RETURN
   10	CONTINUE
C
C	Load 2 augmented arrays of data so that indexing the convolution
C	is easy.  The "picture frame" is loaded all the way out to MS_2
C	(rather than is_2) to simplify indexing.  The fill is RMISS
C	(missing) above and below, and periodic left and right.
C
	is_2 = ismth / 2
	DO  j = 1, LT
	DO  i = 1, LN
	    aug (MS_2 + i, MS_2 + j, 1) = arrin (i, j)
	    aug (MS_2 + i, MS_2 + j, 2) = arrin (i, j)
	END DO
	END DO
C
	DO  j = 1, MS_2
	DO  i = 1, LN + 2 * MS_2
	    aug (i, j            , 1) = RMISS
	    aug (i, j + MS_2 + LT, 1) = RMISS
	    aug (i, j            , 2) = RMISS
	    aug (i, j + MS_2 + LT, 2) = RMISS
	END DO
	END DO
C
	DO  j = MS_2 + 1, MS_2 + LT
	DO  i = 1,        MS_2
	    aug (i,             j, 1) = aug (i + LN  , j, 1)
	    aug (i + LN + MS_2, j, 1) = aug (i + MS_2, j, 1)
	END DO
	END DO
C
C	Section 1: If npass is .LE. 0, apply the smoother to originally
C	missing boxes until no boxes are missing.  The DO WHILE 
C	successively fills in missings that have at least one non-missing
C	value somewhere in the 3x3 template.  But, because it tests for
C	missings on the original (unchanging) array of data, originally
C	missing boxes keep getting recomputed even after they're filled
C	until all holes are closed.  FILLDC shifted to a scheme indexing
C	on the previous ping-pong array to avoid this but we retain the
C	original scheme here because:
C	1) the extra smoothing laterally along the original edge of the
C	   hole isn't necessarily bad,
C	2) to maintain consistent code with the Section 2 code, and
C	3) for continuity with previous work.
C
	nfill = 0
	m1    = 1
	m2    = 2
	IF  ( npass .LT. 0 )  THEN
C
C	    Check that there are holes to fill.
C
	    DO  j = 1 + LTSKP, LT - LTSKP
	    DO  i = 1,         LN
		IF  ( arrin (i, j) .EQ. RMISS )  GO TO 50
	    END DO
	    END DO
	    done = .TRUE.
	    GO TO 55
   50	    CONTINUE
	    done = .FALSE.
   55	    CONTINUE
C
	    DO  WHILE ( .NOT. done )
		nfill = nfill + 1
C
C		Do the convolution, indexing on aug corner and smth center.
C
		DO  j = MS_2 + 1 + LTSKP, MS_2 + LT - LTSKP
		DO  i = MS_2 + 1,         MS_2 + LN
		    wt  = 0.
		    xwt = 0.
		    IF  ( arrin (i - MS_2, j - MS_2) .EQ. RMISS )  THEN
			DO  jj = -is_2, is_2
			DO  ii = -is_2, is_2
			    IF  ( aug (ii + i, jj + j, m1) .NE. RMISS )  
     +								    THEN
				wt  = wt  + 
     +				    smth (ii + is_2 + 1, jj + is_2 + 1)
				xwt = xwt + 
     +				    smth (ii + is_2 + 1, jj + is_2 + 1)*
     +		 		    aug  (ii + i,        jj + j, m1)
			    END IF
			END DO
			END DO
			augwt (i, j) = wt
			IF  ( wt .EQ. 0 )  THEN
			    aug (i, j, m2) = RMISS
			  ELSE
			    aug (i, j, m2) = xwt / wt
			END IF
		    END IF
		END DO
		END DO
C
C		Wrap up the smoothing by resetting the ping-pong indices
C		m1, m2 and filling the lateral boundaries.
C
		IF  ( m1 .EQ. 1 )  THEN
		    m1 = 2
		    m2 = 1
		  ELSE
		    m1 = 1
		    m2 = 2
		END IF
		DO  j = MS_2 + 1, MS_2 + LT
		DO  i = 1,        MS_2
		    aug (i,             j, m1) = aug (i + LN  , j, m1)
		    aug (i + LN + MS_2, j, m1) = aug (i + MS_2, j, m1)
		END DO
		END DO
C
C		Check that there are still holes to fill.
C
		DO  j = MS_2 + 1 + LTSKP, MS_2 + LT - LTSKP
		DO  i = MS_2 + 1,         MS_2 + LN
		    IF  ( aug (i, j, m1) .EQ. RMISS )  GO TO 150
		END DO
		END DO
		done = .TRUE.
		GO TO 155
  150		CONTINUE
		done = .FALSE.
  155		CONTINUE
	    END DO
	    WRITE (*, *)  'It took', nfill, ' passes to fill holes'
	    npass = nfill * 5
	END IF
C
C	Done with optional code to find npass.  Now apply the smoother
C	a total of npass times (already done nfill times in the optional
C	part; nfill = 0 if npass started .GE. 0).  The ping-pong indices
C	m1, m2 are set such that m1 is the current field.
C
	IF  ( npass .GT. 0 )  THEN
	    DO  n = 1, npass - nfill
		DO  j = MS_2 + 1 + LTSKP, MS_2 + LT - LTSKP
		DO  i = MS_2 + 1,         MS_2 + LN
		    wt  = 0.
		    xwt = 0.
		    IF  ( arrin (i - MS_2, j - MS_2) .EQ. RMISS )  THEN
			DO  jj = -is_2, is_2
			DO  ii = -is_2, is_2
			    IF  ( aug (ii + i, jj + j, m1) .NE. RMISS )  
     +								    THEN
				wt  = wt  + 
     +				    smth (ii + is_2 + 1, jj + is_2 + 1)
				xwt = xwt + 
     +				    smth (ii + is_2 + 1, jj + is_2 + 1)*
     +		 		    aug  (ii + i,        jj + j, m1)
			    END IF
			END DO
			END DO
			augwt (i, j) = wt
			IF  ( wt .EQ. 0. )  THEN
			    aug (i, j, m2) = RMISS
			  ELSE
			    aug (i, j, m2) = xwt / wt
			END IF
		    END IF
		END DO
		END DO
C
C		Wrap up the smoothing by resetting the ping-pong indices
C		m1, m2 and filling the lateral boundaries.
C
		IF  ( m1 .EQ. 1 )  THEN
		    m1 = 2
		    m2 = 1
		  ELSE
		    m1 = 1
		    m2 = 2
		END IF
		DO  j = MS_2 + 1, MS_2 + LT
		DO  i = 1,        MS_2
		    aug (i,             j, m1) = aug (i + LN  , j, m1)
		    aug (i + LN + MS_2, j, m1) = aug (i + MS_2, j, m1)
		END DO
		END DO
	    END DO
	END IF
C
C	Even if npass = 0, we need to copy the "final" array to the output
C	array.
C
	DO  j = 1, LT
	DO  i = 1, LN
	    arrout (i, j) = aug (MS_2 + i, MS_2 + j, m1)
	END DO
	END DO
C
	iret = 0
	RETURN
	END
