function [] = GPCPcdr_m5_DiagPlots_AnomMaps(yyyy,mm,filetype,fontsize);
% Matlab function to plot anomaly map for a specific month from either 
% a CDR or ICDR NetCDF file.
%
% Arguments:
%
%  yyyy, mm - 4 digit year and 2 digit month
%  filetype - either 'cdr', 'icdr' or 'interim' (default='cdr')
%        'cdr' - plot a field from a CDR file
%        'icdr' - plot a field form an ICDR/NRT file 
%        'interim' - plot an interim field
%  font size - size of basic font (device dependent; default=14)
%
% Run from unix using:
% /usr/local/bin/matlab -nosplash -nodisplay -nodesktop -r "path(path,'GPCPcdr_m5/GPCPcdr_m5_DiagPlots/'); GPCPcdr_m5_DiagPlots_AnomMaps(2013,07,'icdr',16); exit;"

% Writen by MRP Sapiano, Dec 2013

% Check inputs and set default
if nargin < 2, help(mfilename), return, 
elseif nargin == 2, filetype='cdr'; fontsize=40;
elseif nargin == 3, fontsize=40;
elseif nargin >4, help(mfilename), return,
end;
field='precip';

% add path to directory where some useful functions are stored
path(path,'GPCPcdr_m5/GPCPcdr_m5_DiagPlots/');

% load coastline for plot
load coast; coast_lat=[lat; NaN; lat]; 
  coast_long=[long; NaN; long+360]; clear lat long;

% check filetype is one of the expected values
if isempty(strmatch(filetype,{'cdr';'icdr'})),
  disp(sprintf('Error: invalid filetype:\n%s',filetype));
  return;
end;


% get name of source file using OptionsM.h or OptionsM_NRT.h
if strcmp(filetype,'icdr'),
  lines=textread('OptionsM_NRT.h','%s','delimiter','\n','whitespace','');
else,
  lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
end;
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));
fname=sprintf('%s/gpcp_%s_v22rB1_y%04d_m%02d.nc',fdir,filetype,yyyy,mm);

% check file exists
if isempty(dir(fname)),
  disp(sprintf('Error: Unable to find file, check path and file exist:\n%s',fname));
  return;
end;

% read field from NC file (use ncload function written by M Sapiano)
data=ncload(fname,field); 

% retrieve field and save in data
% if field does not exist, give warning
if ~isfield(data,field)
  disp(sprintf('Error: Field was not in file:\n%s',field));
  return;
else,
  data=data.(field);
end;








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate mean field from which anomaly is calculated

% Use anomaly from CDR data for DCR and ICDR
lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir1=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));


% read all CDR files
all_years=datevec(now); all_years=1979: all_years(1);

all_data=NaN*ones([144 72 length(all_years)]);
for k=1:length(all_years),
  try,
    data1=ncload(sprintf('%s/gpcp_%s_v22rB1_y%04d_m%02d.nc',fdir1,'cdr',all_years(k),mm),field); 
    all_data(:,:,k)=data1.(field);
  end;
end;
all_data(find((all_data<-900)|(all_data>900)))=NaN;
anom=data-nanmean(all_data,3);

%squeeze(nansum(nansum(all_data)))






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get some plotting stuff ready
data(find(data<0))=NaN;
lat=-90:2.5:87.5; lon=0:2.5:357.5;
clf;

tmp=jet(16); tmp(8:9,:)=1;
colormap(flipud(tmp));

% make plot of field with coast line
imagesc(lon,lat,flipud(anom'));
set(gca,'YLim',[-90 90],'XLim',[0 360]);
hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);
caxis([-4 4]);
h=colorbar('v'); set(h,'FontSize',fontsize);

% set text values
set(gca,'YDir','normal','FontSize',fontsize,'YTick',[-90 -60 -30 0 30 60 90],'XTick',[0 60 120 180 240 300 360]);
title(['GPCP ' upper(filetype) ' Precipitation Anomaly ' datestr(datenum([yyyy mm 1]),'mmm yyyy') ', mm day^-^1'],'FontSize',round(fontsize*1.5));
%title(sprintf('%s Anom %s, %04d/%02d',filetype,field,yyyy,mm),'FontSize',fontsize);

% print to file
set(gcf,'PaperPosition',[0.25 2.5 12 8]);
print('-dpng',sprintf('%sDiagPlots/DiagAnomMap_%s_%s_%04d%02d',fdir,filetype,field,yyyy,mm));





