function [] = GPCPcdr_m5_DiagPlots_maps(yyyy,mm,filetype,field,fontsize);
% Matlab function to plot a map for a specific month from either 
% a CDR or ICDR NetCDF file or one of the Interim fields.  User 
% must specify the correct field name to plot; an error is 
% generated if the requested field does not exist.
%
% Arguments:
%
%  yyyy, mm - 4 digit year and 2 digit month
%  filetype - either 'cdr', 'icdr' or 'interim' (default='cdr')
%        'cdr' - plot a field from a CDR file
%        'icdr' - plot a field form an ICDR/NRT file 
%        'interim' - plot an interim field
%  field - name of field to plot (default='precip')
%  font size - size of basic font (device dependent; default=14)
%
% Values for field:
% If filetype is 'cdr' or 'icdr' then 'field' must be 'precip' or 
% 'precip_error'. If filetype os 'interim', then 'field' must be 
% one of the values from the following table.  There are three
% different data periods:
%   1  Jan 79 to Dec 85
%   2  Jan 86 to jul 87 (plus dec 87)
%   3  Aug 87-present (excl dec 87)
%
% Field  Data
% Name   Period Name 
%  pop       1  Outgoing Longwave Radiation (OLR) Precipitation 
%                  Index (OPI) precipitation estimate
%  pms     123  Multi-satellite precipitation
%  pga     123  Gauge precipitation
%  psg     123  Satellite/gauge precipitation
%  eop     1    Outgoing Longwave Radiation (OLR) Precipitation  
%                  Index (OPI) precipitation random error
%  ems     123  Multi-satellite precipitation random error
%  ega     123  Gauge precipitation random error
%  esg     123  Satellite/gauge precipitation random error
%  nga     123  Gauge precipitation number of gauges
%  pag      23  Adjusted GOES Precipitation Index (AGPI)  
%                  precipitation estimate
%  eag      23  Adjusted GOES Precipitation Index (AGPI)  
%                  precipitation random error
%  pop      2   Outgoing Longwave Radiation (OLR) Precipitation  
%                  Index (OPI) precipitation estimate
%  pgp      23  GOES Precipitation Index (GPI) precipitation  
%                  estimate
%  ngp      23  GOES Precipitation Index (GPI) image number
%  pse       3  SSM/I emission precipitation estimate
%  nse       3  SSM/I emission precipitation number of samples
%  pss       3  SSM/I scattering precipitation estimate
%  nss       3  SSM/I scattering precipitation number of samples
%  psc       3  SSM/I composite precipitation estimate
%  ssc       3  SSM/I composite precipitation source
%  nsc       3  SSM/I composite precipitation number of samples
%  pst       3  Merged SSMI/TOVS precipitation estimate
%  est       3  Merged SSMI/TOVS precipitation random error
%  sst       3  Merged SSMI/TOVS precipitation source
%  ptv       3  TOVS precipitation estimate
%
%
% Run from unix using:
% /usr/local/bin/matlab -nosplash -nodisplay -nodesktop -r "path(path,'GPCPcdr_m5/GPCPcdr_m5_DiagPlots/'); GPCPcdr_m5_DiagPlots_maps(2013,07,'icdr','precip',16); exit;"

% Writen by MRP Sapiano, Oct 2013

% Check inputs and set defaults
if nargin < 2, help(mfilename), return, 
elseif nargin == 2, filetype='cdr'; field='precip'; fontsize=40;
elseif nargin == 3, field='precip'; fontsize=40;
elseif nargin == 4, fontsize=40;
elseif nargin >5, help(mfilename), return,
end;

% add path to directory where some useful functions are stored
path(path,'GPCPcdr_m5/GPCPcdr_m5_DiagPlots/');

% load coastline for plot
load coast; coast_lat=[lat; NaN; lat]; 
  coast_long=[long; NaN; long+360]; clear lat long;

% check filetype is one of the expected values
if isempty(strmatch(filetype,{'cdr';'icdr';'interim'})),
  disp(sprintf('Error: invalid filetype:\n%s',filetype));
  return;
end;

% check field is one of the expected values
data_type='';
if strmatch(field,{'precip';'pms';'pga';'psg';'pop';'pag';'pop';'pgp';'pse';'pss';'psc';'pst';'ptv'}),
  data_type='p';
elseif strmatch(field,{'precip_error';'eop';'ems';'ega';'esg';'eag';'est'}),
  data_type='e';
elseif strmatch(field,{'nga';'ngp';'nse';'nss';'nsc'}),
  data_type='n';
elseif strmatch(field,{'ssc';'sst'}),
  data_type='s';
else,
  disp(sprintf('Error: invalid field:\n%s',field));
  return;
end;


% get name of source file using OptionsM.h or OptionsM_NRT.h
if strcmp(filetype,'icdr'),
  lines=textread('OptionsM_NRT.h','%s','delimiter','\n','whitespace','');
else,
  lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
end;
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));
fname=sprintf('%s/gpcp_%s_v22rB1_y%04d_m%02d.nc',fdir,filetype,yyyy,mm);

% check file exists
if isempty(dir(fname)),
  disp(sprintf('Error: Unable to find file, check path and file exist:\n%s',fname));
  return;
end;

% read field from NC file (use ncload function written by M Sapiano)
data=ncload(fname,field); 

% retrieve field and save in data
% if field does not exist, give warning
if ~isfield(data,field)
  disp(sprintf('Error: Field was not in file:\n%s',field));
  return;
else,
  data=data.(field);
end;


% get some plotting stuff ready
data(find(data<0))=NaN;
lat=-90:2.5:87.5; lon=0:2.5:357.5;
clf;

% get suitable colormap
if strmatch(data_type,{'p';'e'}), % precip, error data
  [raincols] = RainCols(16);
  colormap(raincols);
elseif strmatch(data_type,{'n';'s'}), % count, source data
  colomap(jet(32));
end;

% make plot of field with coast line
imagesc(lon,lat,flipud(data'));
set(gca,'YLim',[-90 90],'XLim',[0 360]);
hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);

% make appropriate colorbar 
if strmatch(data_type,{'p';'e'}), % precip, error data
  caxis([0 16]);
end;
h=colorbar('v'); set(h,'FontSize',fontsize);

% set text values
set(gca,'YDir','normal','FontSize',fontsize,'YTick',[-90 -60 -30 0 30 60 90],'XTick',[0 60 120 180 240 300 360]);
if strmatch(field,'precip'),
  title(['GPCP ' upper(filetype) ' Precipitation ' datestr(datenum([yyyy mm 1]),'mmm yyyy') ', mm day^-^1'],'FontSize',round(fontsize*1.5));
else
  title(['GPCP ' upper(filetype) ' ' field ' ' datestr(datenum([yyyy mm 1]),'mmm yyyy')],'FontSize',round(fontsize*1.5));
end
%title(sprintf('%s %s, %04d/%02d',filetype,field,yyyy,mm),'FontSize',fontsize);

% print to file
set(gcf,'PaperPosition',[0.25 2.5 12 8]);
print('-dpng',sprintf('%sDiagPlots/DiagMap_%s_%s_%04d%02d',fdir,filetype,field,yyyy,mm));







