function [] = GPCPcdr_m5_Products_Anoms(yyyy,mm);
% Matlab function to calculate and plot anomalies for 1, 3, 6 months and 1 year
%
% Run from unix using:
% /usr/local/bin/matlab -nosplash -nodisplay -nodesktop -r "path(path,'GPCPcdr_m5/GPCPcdr_m5_Products/'); GPCPcdr_m5_Products_Anoms(2014,10); exit;"

% Writen by MRP Sapiano, Nov 2014


% Check inputs and set default
if nargin ~= 2, disp('need yyyy mm'); help(mfilename), return, end;

% add path to directory where some useful functions are stored
path(path,'GPCPcdr_m5/GPCPcdr_m5_Products/');



% check target date is reasonable
targdate=datenum([yyyy mm 1]);
if ((targdate<datenum('01jan1979'))|(targdate>datenum('01jan2030'))), 
disp('Date outside reasonable bounds'); help(mfilename), return, end;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% read data

% Calculate potential dates and initialize precip variable
alldates=datevec(datenum('01jan1979'):now);
alldates(:,3)=1; alldates=unique(datenum(alldates));
precip=NaN*ones([144 72 length(alldates)]);



%%%%%%%%%
% Read all available GPCP CDR data 

% Get CDR directory from OptionsM.h
lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));

for k=1:length(alldates), clear data;
  fname=sprintf('%s/gpcp_cdr_v22rB1_y%s_m%s.nc',fdir,datestr(alldates(k),'yyyy'),datestr(alldates(k),'mm'));
  if ~isempty(dir(fname)),  % check file exists
    data=ncload(fname,'precip'); 
    if isfield(data,'precip'); % check that field exists
      data.precip(find(data.precip<-9900))=NaN;
      test=nanmean(nanmean(data.precip)); % test that precip is reasonable
      if (test>=0)&(test<=10),
        precip(:,:,k)=data.precip;
      end;
    end;
  end;
end;


%%%%%%%%%
% Read ICDR data and backfill for up to last 12 months

% get months for which ICDR data is required
test=squeeze(sum(sum(isnan(precip))));
ksub=find(test~=0);
ksub=ksub(find(ksub>=(length(alldates)-11)));

% Get ICDR directory from OptionsM_NRT.h
lines=textread('OptionsM_NRT.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));

for k=ksub', clear data;
  fname=sprintf('%s/gpcp_icdr_v22rB1_y%s_m%s.nc',fdir,datestr(alldates(k),'yyyy'),datestr(alldates(k),'mm'));
  if ~isempty(dir(fname)),  % check file exists
    data=ncload(fname,'precip'); 
    if isfield(data,'precip'); % check that field exists
      data.precip(find(data.precip<-9900))=NaN;
      test=nanmean(nanmean(data.precip)); % test that precip is reasonable
      if (test>=0)&(test<=10),
        precip(:,:,k)=data.precip;
        % print months that where ICDR was used
        disp(['ICDR used for ' datestr(alldates(k),'yyyy mm')]);
      end;
    end;
  end;
end;

% print months that where not read successfully 
test=squeeze(sum(sum(isnan(precip))));
disp(char({'Summary of missing CDR data:';'yyyy mmm   Nmiss'; [datestr(alldates(find(test~=0)),'yyyy mm    ') num2str(test(find(test~=0)))]}));


% flip lats
precip=flipdim(precip,2);





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load climatology
fid=fopen('GPCPv2p2_clims_79to13_aug14.txt','rt'); trash=fscanf(fid,'%s',5);
  clim_1mon=reshape(fscanf(fid,'%*d %*f %*f %*f %f',144*72*12),[144 72 12]);
  clim_3mon=reshape(fscanf(fid,'%*f %*f %*f %*f %f',144*72*12),[144 72 12]);
  clim_6mon=reshape(fscanf(fid,'%*f %*f %*f %*f %f',144*72*12),[144 72 12]);
  clim_12mon=reshape(fscanf(fid,'%*f %*f %*f %*f %f',144*72),[144 72]);
fclose(fid);

anom=[]; percanom=[]; percnorm=[];
Nmons=[1 3 6 12];
for k=1:4
  % get correct climatology
  eval(sprintf('clim=clim_%dmon;',Nmons(k)));

  % month for which anomaly is required (requires some averaging)
  idx=find(alldates==targdate)-[0:(Nmons(k)-1)];
  if max(abs(alldates(idx(1:(end-1)))-alldates(idx(2:end))))>45,
    disp('Appear to be missing months in input'); return; end;

  % get anomaly, percent anomaly and percent of Normal (climatology)
  targmon=datevec(targdate); targmon=targmon(2);
  if Nmons(k)==12, targmon=1; end;
  anom(:,:,k)=nanmean(precip(:,:,idx),3)-clim(:,:,targmon);
  percanom(:,:,k)=100*(nanmean(precip(:,:,idx),3)-clim(:,:,targmon))./clim(:,:,targmon);
  percnorm(:,:,k)=100*nanmean(precip(:,:,idx),3)./clim(:,:,targmon);
end;





%%%%%%%%%%%%%
% Establish some details

% Get CDR directory from OptionsM.h
lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));
fdir=[fdir '/Anoms/'];
if isempty(dir(fdir)), [s w]=unix(['mkdir ' fdir]); end;

% load coastline for plot
load coast; coast_lat=[lat; NaN; lat]; 
  coast_long=[long; NaN; long+360]; clear lat long;






%%%%%%%%%%%%%
% make Anomaly plot of all four time scales

%colormap([.7 .7 .7; .3 0 0; .3 0 0; .6 0 0; .6 0 0; 1 0 0; 1 0 0; 1 .6 0; 1 .6 0; 1 1 0; 1 1 1; 1 1 1; .2 1 .8; 0 .8 1; 0 .8 1; 0 .4 1; 0 .4 1; 0 0 1; 0 0 1; 0 0 .6; 0 0 .6]);
colormap([.7 .7 .7; .3 0 0; .5 .2 0; .6 .4 .2; .8 .7 .4; 1 1 1; 1 1 1; .7 .8 1; 0 .4 1; 0 0 1; 0 0 .4]);

tmpnames={'Monthly Anomaly';'3-Monthly Anomaly ending';'6-Monthly Anomaly ending';'Annual Anomaly ending'};
lims=[5 5 2.5 2.5];
lat=-90:2.5:87.5; lon=0:2.5:357.5;

aveperiod={'01mon';'03mon';'06mon';'12mon'};
for k=1:4, colims=lims(k)*[-1 1]; colinc=(colims(2)-colims(1))/20;
  clf; 
  tmp=anom(:,:,k); tmp(find(tmp<colims(1)))=colims(1);
  imagesc(lon,lat,tmp'); set(gca,'YDir','normal','FontSize',14); 
  caxis(colims-[colinc 0]); h=colorbar('h'); set(h,'XLim',colims,'FontSize',18);
  hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);
  title([char(tmpnames(k)) ' ' datestr(targdate,'mmm yyyy')],'FontSize',30);

  set(gcf,'PaperPosition',[0.25 2.5 18 12]);
  print('-dpng',[fdir 'Anoms_'  char(aveperiod(k)) datestr(targdate,'yyyymm')]);
end;




%%%%%%%%%%%%%
% make Percent anomaly plot of all four time scales
colormap([.7 .7 .7; .3 0 0; .5 .2 0; .6 .4 .2; .8 .7 .4; 1 1 1; 1 1 1; .7 .8 1; 0 .4 1; 0 0 1; 0 0 .4]);

tmpnames={'Monthly % Anomaly';'3-Monthly % Anomaly ending';'6-Monthly % Anomaly ending';'Annual % Anomaly ending'};
lims=[100 100 100 100];
lat=-90:2.5:87.5; lon=0:2.5:357.5;

aveperiod={'01mon';'03mon';'06mon';'12mon'};
for k=1:4, colims=100+lims(k)*[-1 1]; colinc=(colims(2)-colims(1))/10;
  clf; 
  tmp=percanom(:,:,k); tmp(find(tmp<colims(1)))=colims(1);
  imagesc(lon,lat,tmp'); set(gca,'YDir','normal','FontSize',14); 
  caxis(colims-[colinc 0]); h=colorbar('h'); set(h,'XLim',colims,'FontSize',14);
  hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);
  title([char(tmpnames(k)) ' ' datestr(targdate,'mmm yyyy')],'FontSize',20);

  set(gcf,'PaperPosition',[0.25 2.5 18 12]);
  print('-dpng',[fdir 'PercAnom_'  char(aveperiod(k)) datestr(targdate,'yyyymm')]);
end;






%%%%%%%%%%%%%
% make Percent of Normal plot of all four time scales
colormap([.7 .7 .7; .3 0 0; .5 .2 0; .6 .4 .2; .8 .7 .4; 1 1 1; 1 1 1; .7 .8 1; 0 .4 1; 0 0 1; 0 0 .4]);

tmpnames={'Monthly % of Normal';'3-Monthly % of Normal ending';'6-Monthly % of Normal ending';'Annual % of Normal ending'};
lims=[100 100 100 100];
lat=-90:2.5:87.5; lon=0:2.5:357.5;

aveperiod={'01mon';'03mon';'06mon';'12mon'};
for k=1:4, colims=100+lims(k)*[-1 1]; colinc=(colims(2)-colims(1))/10;
  clf; 
  tmp=percnorm(:,:,k); tmp(find(tmp<colims(1)))=colims(1);
  imagesc(lon,lat,tmp'); set(gca,'YDir','normal','FontSize',14); 
  caxis(colims-[colinc 0]); h=colorbar('h'); set(h,'XLim',colims,'FontSize',14);
  hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);
  title([char(tmpnames(k)) ' ' datestr(targdate,'mmm yyyy')],'FontSize',20);

  set(gcf,'PaperPosition',[0.25 2.5 18 12]);
  print('-dpng',[fdir 'PercNorm_'  char(aveperiod(k)) datestr(targdate,'yyyymm')]);
end;







disp(['Anomaly plots stored in ' fdir]);


