function [] = GPCPcdr_m5_Products_SPI(yyyy,mm);
% Matlab function to calculate and plot the SPI using CDR data and 
% the most recent ICDR data
%
%
%
% Run from unix using:
% /usr/local/bin/matlab -nosplash -nodisplay -nodesktop -r "path(path,'GPCPcdr_m5/GPCPcdr_m5_Products/'); GPCPcdr_m5_Products_SPI(2008,01); exit;"


% Writen by MRP Sapiano, Oct 2014


% Check inputs and set default
if nargin ~= 2, disp('need yyyy mm'); help(mfilename), return, end;

% add path to directory where some useful functions are stored
path(path,'GPCPcdr_m5/GPCPcdr_m5_Products/');



% check target date is reasonable
targdate=datenum([yyyy mm 1]);
if ((targdate<datenum('01jan1979'))|(targdate>datenum('01jan2030'))), 
disp('Date outside reasonable bounds'); help(mfilename), return, end;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% read data

% Calculate potential dates for the ESPI and initialize precip variable
alldates=datevec(datenum('01jan1979'):now);
alldates(:,3)=1; alldates=unique(datenum(alldates));
precip=NaN*ones([144 72 length(alldates)]);



%%%%%%%%%
% Read all available GPCP CDR data 

% Get CDR directory from OptionsM.h
lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));

for k=1:length(alldates), clear data;
  fname=sprintf('%s/gpcp_cdr_v22rB1_y%s_m%s.nc',fdir,datestr(alldates(k),'yyyy'),datestr(alldates(k),'mm'));
  if ~isempty(dir(fname)),  % check file exists
    data=ncload(fname,'precip'); 
    if isfield(data,'precip'); % check that field exists
      data.precip(find(data.precip<-9900))=NaN;
      test=nanmean(nanmean(data.precip)); % test that precip is reasonable
      if (test>=0)&(test<=10),
        precip(:,:,k)=fliplr(data.precip);
      end;
    end;
  end;
end;


%%%%%%%%%
% Read ICDR data and backfill for up to last 12 months

% get months for which ICDR data is required
test=squeeze(sum(sum(isnan(precip))));
ksub=find(test~=0);
ksub=ksub(find(ksub>=(length(alldates)-11)));

% Get ICDR directory from OptionsM_NRT.h
lines=textread('OptionsM_NRT.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));

for k=ksub', clear data;
  fname=sprintf('%s/gpcp_icdr_v22rB1_y%s_m%s.nc',fdir,datestr(alldates(k),'yyyy'),datestr(alldates(k),'mm'));
  if ~isempty(dir(fname)),  % check file exists
    data=ncload(fname,'precip'); 
    if isfield(data,'precip'); % check that field exists
      data.precip(find(data.precip<-9900))=NaN;
      test=nanmean(nanmean(data.precip)); % test that precip is reasonable
      if (test>=0)&(test<=10),
        precip(:,:,k)=fliplr(data.precip);
        % print months that where ICDR was used
        disp(['ICDR used for ' datestr(alldates(k),'yyyy mm')]);
      end;
    end;
  end;
end;

% print months that where not read successfully 
test=squeeze(sum(sum(isnan(precip))));
disp(char({'Summary of missing CDR data:';'yyyy mmm   Nmiss'; [datestr(alldates(find(test~=0)),'yyyy mm    ') num2str(test(find(test~=0)))]}));






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% calculate SPI for various time scales
% Technique follows Lloyd-hughes and Saunders 2002 (IJC)

SPIvals=[];
for k=1:4
  % set month to analyze
  idx=find(alldates==targdate);

  % Set months to average and alpha/beta filename
  if k==1, ii=idx;          % Monthly
    fname='SPI_Monthly_AlphaBeta_GPCPv2p2_79to13_aug14.txt'; 
  elseif k==2, ii=idx-[0:2];  % 3 monthly
    fname='SPI_3Monthly_AlphaBeta_GPCPv2p2_79to13_aug14.txt';
  elseif k==3, ii=idx-[0:5];  % 6 monthly
    fname='SPI_6Monthly_AlphaBeta_GPCPv2p2_79to13_aug14.txt';
  elseif k==4, ii=idx-[0:11]; % Annual
    fname='SPI_Annual_AlphaBeta_GPCPv2p2_79to13_aug14.txt';
  end;

  % Average data to required timescale
  data1=nanmean(precip(:,:,ii),3); mon=datevec(alldates); mon=mon(idx,2);

  % read Alpha and beta - Annual file is different...
  if k~=4,
    fid=fopen(fname,'rt'); trash=fscanf(fid,'%s',5);
      AlphaBeta=fscanf(fid,'%*f %*f %*d %f %f',inf); fclose(fid);
    AlphaBeta=reshape(AlphaBeta,[2 144 72 12]);
    alpha=fliplr(squeeze(AlphaBeta(1,:,:,mon)));
    beta=fliplr(squeeze(AlphaBeta(2,:,:,mon)));
  else,
    fid=fopen(fname,'rt'); trash=fscanf(fid,'%s',4);
      AlphaBeta=fscanf(fid,'%*f %*f %f %f',inf); fclose(fid);
    AlphaBeta=reshape(AlphaBeta,[2 144 72]);
    alpha=fliplr(squeeze(AlphaBeta(1,:,:)));
    beta=fliplr(squeeze(AlphaBeta(2,:,:)));
  end;


  % now need to find the cumulative probability 
  % Use the incomplete gamma function (which can be used in Fortran
  %        based on numRecipes function gammp.f)
  % Gamma [gamcdf] and Incomplete Gamma [gammainc] give same answer
  data2=data1; data2(find(data2==0))=NaN;
  G=[];
  for i1=1:144, for i2=1:72,
    G(i1,i2)=gammainc(data2(i1,i2)/beta(i1,i2),alpha(i1,i2));
    %G(i1,i2)=gamcdf(data2(i1,i2),alpha(i1,i2),beta(i1,i2));
  end; end;

  % adjust for zero rainfall amounts (not many for monthly data)
  q=nansum(data1==0,3)./nansum(~isnan(data2),3);
  H=q+(1-q).*G;

  % transform H to SPI using approximation from Abramowitz and Stegun (1965)
  %calculate t - different for H<=0.5 and H>0.5
  t=sqrt(log(1./H.^2));
  t(find(H>0.5))=sqrt(log(1./(1-H(find(H>0.5))).^2));
  SPI=t-(2.515517+0.802853.*t+0.010328.*t.*t)./(1+1.432788.*t+0.189269.*t.*t+0.001308.*t.*t.*t);
  SPI(find(H<=0.5))=SPI(find(H<=0.5))*-1;

  % output SPI to SPIvals
  SPIvals(:,:,k)=SPI;
end;





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% make plots and output

% Get CDR directory from OptionsM.h
lines=textread('OptionsM.h','%s','delimiter','\n','whitespace','');
idx=strmatch('#define OutputPATH',lines);
fdir=char(regexprep(lines(idx,:),{'#define OutputPATH',' ','"'},''));
fdir=[fdir '/SPI/'];
if isempty(dir(fdir)), [s w]=unix(['mkdir ' fdir]); end;


% load coastline for plot
load coast; coast_lat=[lat; NaN; lat]; 
  coast_long=[long; NaN; long+360]; clear lat long;
load usalo;


% make plot of all four time scales
tmp=[0 0 0; .5 .25 .25; 1 0 0; 1 .5 0; 1 1 0; 1 1 1; .7 1 0; 0 .7 0; 0 .5 .5; 0 0 1; .6 0 1];
colormap([.7 .7 .7; tmp(sort([repmat(2:10,1,3) 1 2 4 4 8 8 10 11 6*ones(1,7)]),:)]);

tmpnames={'Monthly SPI';'3-Monthly SPI ending';'6-Monthly SPI ending';'Annual SPI ending'};

lat=-90:2.5:87.5; lon=0:2.5:357.5;
aveperiod={'01mon';'03mon';'06mon';'12mon'};
for k=1:4,
  clf; 
  tmp=SPIvals(:,:,k); tmp(find(tmp<-2.1))=-2.1;
  imagesc(lon,lat,tmp'); set(gca,'YDir','normal','FontSize',26); 
  set(gca,'YTick',[],'XTick',[]);
  caxis([-2.2 2.1]); h=colorbar('h'); set(h,'XLim',[-2.1 2.1],'XTick',[-2 -1.6 -1.3 -.8 -.5 .5 .8 1.3 1.6 2],'FontSize',26);
  hold on; plot(coast_long,coast_lat,'-k','LineWidth',2);
  title([char(tmpnames(k)) ' ' datestr(targdate,'mmm yyyy')],'FontSize',40);

  set(gcf,'PaperPosition',[0.25 2.5 18 12]);
  print('-dpng',[fdir 'SPI_' char(aveperiod(k)) datestr(targdate,'_yyyymm')]);

  % make USA version
  hold on; plot(uslon+360,uslat,'--k','LineWidth',2);
  set(gca,'YLim',[23 50],'XLim',[210 310]);
  set(gcf,'PaperPosition',[0.25 2.5 18 10]);
  print('-dpng',[fdir 'SPI_USonly_' char(aveperiod(k)) datestr(targdate,'_yyyymm')]);
end;

disp(['SPI plots stored in ' fdir]);

