#include <stdio.h>
#include <netcdf.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <unistd.h>

/* Required for error checking reading NetCDF files */
#define ERR(e) {fprintf(stderr,"Error (CDR Write): %s\n", nc_strerror(e)); return ;;}
#include "../../OptionsM.h"

static time_t get_epoch_time(char *time_str)
{
  struct tm tm;
  time_t t = 0;
  if (strptime(time_str, "%Y-%m-%dT%H:%M:%SZ", &tm)) {
    tm.tm_isdst = -1;  // never daylight saving time
    t = mktime(&tm)/86400;
  }
  return t;
}

int Write_CDR_nc(char *dirname, char *filename, char *VersNum, char *CompName, char *current_time_str, int yyyy, int mm)
{
  int     i,j;
  int     ncid;   /* Netcdf file unit */
  int     retval; /* Status flag for netcdf files */
  int     yyyymm;
  FILE   *fopen();
  FILE   *fp_precip;
  FILE   *fp_precip_error;
  char    fname_precip[256];
  char    fname_precip_error[256];
  char    yyyy_mm_dd[52];
  char    fname[512];
  char    tmpchar1[256], tmpchar2[256];
  char    tmpcomma[2];
  int     Ndays[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
  int     LeapYear;

  // Dimension ids
  int     std_dims[3];
  int     nlat_dim;
  int     nlon_dim;
  int     lat_dims[2];
  int     lon_dims[2];
  int     time_dims[2];
  int     time_dim;
  int     nv_dim;

  // Variable ids
  int     latitude_var;
  int     longitude_var;
  int     time_var;
  int     lat_bounds_var;
  int     lon_bounds_var;
  int     time_bounds_var;
  int     precip_var;
  int     precip_error_var;

  // Static global attributes
  char    conventions[]               = "CF-1.6, ACDD 1.3";
  char    title[]                     = "Global Precipitation Climatatology Project (GPCP) Climate Data Record (CDR), Monthly V2.3";
  char    references[]                = "Huffman et al. 1997, http://dx.doi.org/10.1175/1520-0477(1997)078<0005:TGPCPG>2.0.CO;2; Adler et al. 2003, http://dx.doi.org/10.1175/1525-7541(2003)004<1147:TVGPCP>2.0.CO;2; Huffman et al. 2009, http://dx.doi.org/10.1029/2009GL040000; Adler et al. 2016, Global Precipitation Climatology Project (GPCP) Monthly Analysis: Climate Algorithm Theoretical Basis Document (C-ATBD)";
  char    Metadata_Conventions[]      = "CF-1.6, Unidata Dataset Discovery v1.0, NOAA CDR v1.0, GDS v2.0";
  char    standard_name_vocabulary[]  = "CF Standard Name Table (v41, 22 February 2017)";
  char    naming_authority[]          = "gov.noaa.ncdc";
  char    license[]                   = "No constraints on data access or use.";
  char    summary[]                   = "Global Precipitation Climatology Project (GPCP) Monthly Version 2.3 gridded, merged satellite/gauge precipitation Climate data Record (CDR) with errors from 1979 to present.";
  char    keywords[]                  = "EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT";
  char    keywords_vocabulary[]       = "NASA Global Change Master Directory (GCMD) Earth Science Keywords, Version 7.0";
  char    cdm_data_type[]             = "Grid";
  char    project[]                   = "GPCP > Global Precipitation Climatology Project";
  char    processing_level[]          = "NASA Level 3";
  char    creator_name[]              = "Dr. Jian-Jian Wang";
  char    creator_email[]             = "jjwang@umd.edu";
  char    institution[]               = "ACADEMIC > UMD/ESSIC > Earth System Science Interdisciplinary Center, University of Maryland";
  char    publisher_name[]            = "NOAA National Centers for Environmental Information (NCEI)";
  char    publisher_email[]           = "jjwang@umd.edu";
  char    publisher_url[]             = "https://www.ncei.noaa.gov";
  char    geospatial_lat_min[]        = "-90";
  char    geospatial_lat_max[]        = "90";
  char    geospatial_lat_units[]      = "degrees_north";
  char    geospatial_lat_resolution[] = "2.5 degrees";
  char    geospatial_lon_min[]        = "0.";
  char    geospatial_lon_max[]        = "360.";
  char    geospatial_lon_units[]      = "degrees_east";
  char    geospatial_lon_resolution[] = "2.5 degrees";
  char    time_coverage_duration[]    = "P1M";
  char    contributor_name[]          = "Robert Adler, Jian-Jian Wang";
  char    contributor_role[]          = "principalInvestigator, processor and custodian";
  char    acknowledgment[]            = "This project was supported in part by a grant from the NOAA Climate Data Record (CDR) Program for satellites.";
  char    cdr_program[]               = "NOAA Climate Data Record Program for satellites, FY 2011.";
  char    cdr_variable[]              = "precipitation";
  char    metadata_link[]             = "gov.noaa.ncdc:C00979";
  char    spatial_resolution[]        = "2.5 degree";

  // variable global attributes
  char    source[256] = {0};
  char    history[256] = {0};
  char    id[256] = {0};
  char    date_created[256] = {0};
  char    time_coverage_start[256] = {0};
  char    time_coverage_end[256] = {0};
  char    product_version[256] = {0};
  char    platform[1000] = {0};
  char    sensor[1000] = {0};
  char    comment[256] = {0};

  // Attributes for each variable
  char    latitude_longname[]      ="Latitude";
  char    latitude_standard_name[] ="latitude" ;
  char    latitude_units[]         ="degrees_north" ;
  float   latitude_valid_range[2]  ={-90.,90.};
  float   latitude_missing_value   =-9999.;
  char    latitude_bounds[]        ="lat_bounds";

  char    longitude_longname[]      ="Longitude";
  char    longitude_standard_name[] ="longitude" ;
  char    longitude_units[]         ="degrees_east" ;
  float   longitude_valid_range[2]  ={0.,360.};
  float   longitude_missing_value   =-9999.;
  char    longitude_bounds[]        ="lon_bounds";

  char    time_longname[]           ="time";
  char    time_standard_name[] ="time";
  char    time_units[]         ="days since 1970-01-01 00:00:00 0:00";
  char    time_calendar[]           ="Gregorian";
  char    time_axis[]               ="T";

//  char    lat_bounds_units[]        = "degrees_north";
  char    lat_bounds_comment[]      = "latitude values at the north and south bounds of each pixel.";

//  char    lon_bounds_units[]        = "degrees_east";
  char    lon_bounds_comment[]      = "longitude values at the west and east bounds of each pixel.";

//  char    time_bounds_units[]       ="days since 1970-01-01 00:00:00 0:00";
  char    time_bounds_comment[]     ="time bounds for each time value";

  char    precip_longname[]      ="NOAA Climate Data Record (CDR) of GPCP Monthly Satellite-Gauge Combined Precipitation";
  char    precip_standard_name[] ="precipitation amount";
  char    precip_units[]         ="mm/day" ;
  char    precip_coordinates[]   ="time latitude longitude" ;
  float   precip_valid_range[2]  ={0.,100.};
  char    precip_cell_methods[]  ="area: mean time: mean";
  float   precip_missing_value   =-9999.;

  char    precip_error_longname[]      ="NOAA CDR of GPCP Satellite-Gauge Combined Precipitation Error";
  char    precip_error_units[]         ="mm/day" ;
  char    precip_error_coordinates[]   ="time latitude longitude" ;
  float   precip_error_valid_range[2]  ={0.,100.};
  float   precip_error_missing_value   =-9999.;

  // Define fields to hold actual data values
  float    lat_values[72];
  float    lon_values[144];
  float    precip_values[72][144];
  float    precip_values_rev[72][144];
  float    precip_error_values[72][144];
  float    precip_error_values_rev[72][144];
  float    lat_bounds[72][2];
  float    lon_bounds[144][2];
  float    time_bounds[2];

										      
  /********************************************************* 
   * Set values of variable global attributes              *
   *********************************************************/

  // Source is actually static for the CDR file, but dynamic for the interim file
  //sprintf(source,"%s","oc.200101.sg, oc.200101.esg");
  sprintf(source,"oc.%04d%02d.sg",yyyy,mm);

  // Product version
  sprintf(product_version,"%s","v23rB1");

  // History
  memcpy(&yyyy_mm_dd, &current_time_str, 10);
  sprintf(history, "1) %s, Dr. Jian-Jian Wang, U of Maryland, Created beta (B1) file",yyyy_mm_dd);

  // ID
  sprintf(id,"%s",filename);
  sprintf(id,"gpcp_v02r03_%04d%02d",yyyy,mm);

  // Date created
  sprintf(date_created,"%s",current_time_str);

  //Time coverage start/end
  if ( (mm == 2) && (yyyy % 4 == 0) && (yyyy != 2000)) {
    LeapYear=1;
  }
  else {
    LeapYear=0;
  }
  sprintf(time_coverage_start,"%04d-%02d-01T00:00:00Z",yyyy,mm);
  sprintf(time_coverage_end,"%04d-%02d-%02dT23:59:59Z",yyyy,mm,Ndays[mm-1]+LeapYear);

  // Processing computer (comment)
  sprintf(comment,"Processing computer: %s",CompName);

  // epoch based data - depends on month and year
  yyyymm=100*yyyy+mm;
  strcpy(tmpcomma,"");
  strcpy(platform,"");

  // Add AVHRR to platform and sensor global attributes
  if (yyyymm >= 197901 & yyyymm <= 198512){
    sprintf(tmpchar1,"%s%sNOAA POES (Polar Orbiting Environmental Satellites)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sAVHRR>Advanced Very High Resolution Radiometer",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }
  // Add Geo-IR to platform and sensor global attributes
  if (yyyymm >= 198601){
    sprintf(tmpchar1,"%s%sGOES (Geostationary Operational Environmental Satellite), GMS (Japan Geostationary Meteorological Satellite), METEOSAT",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sImager, Imager, Imager",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }
  // Add TOVS to platform and sensor global attributes
  if ((yyyymm >= 198707 & yyyymm <= 200503) & (yyyymm != 200402) & (yyyymm != 198712)) {
    sprintf(tmpchar1,"%s%sTIROS > Television Infrared Observation Satellite",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sTOVS > TIROS Operational Vertical Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }
  // Add AIRS to platform and sensor global attributes
  if ((yyyymm >= 200504) | (yyyymm == 200402)) {
    sprintf(tmpchar1,"%s%sEarth Observing System, AQUA",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sAIRS > Atmospheric Infrared Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }
  // Add SSMI to platform and sensor global attributes
  if ((yyyymm >= 198707 & yyyymm <= 200812) & (yyyymm != 198712)){
    sprintf(tmpchar1,"%s%sDMSP (Defense Meteorological Satellite Program)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sSSMI > Special Sensor Microwave/Imager",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }
  // Add SSMIS to platform and sensor global attributes
  if (yyyymm >= 200901) {
    sprintf(tmpchar1,"%s%sDMSP (Defense Meteorological Satellite Program)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sSSMIS > Special Sensor Microwave Imager/Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  

  /*********************************************************
   * Start writing to file                                 *
   * The file is opened in define mode                     *
   *********************************************************/
  
  /* Open NetCDF file */
  sprintf(fname,"%s%s",dirname, filename);
  if (retval = nc_create(fname, NC_NETCDF4|NC_SHARE, &ncid)) ERR(retval);

  /* Define/write dimensions and dimid */
  if (retval = nc_def_dim(ncid, "latitude", 72, &nlat_dim)) ERR(retval);
  if (retval = nc_def_dim(ncid, "longitude", 144, &nlon_dim)) ERR(retval);
  if (retval = nc_def_dim(ncid, "time", 1, &time_dim)) ERR(retval);
  if (retval = nc_def_dim(ncid, "nv", 2, &nv_dim)) ERR(retval);
  std_dims[0]=time_dim;
  std_dims[1]=nlat_dim;
  std_dims[2]=nlon_dim;
  lat_dims[0]=nlat_dim;
  lat_dims[1]=nv_dim;
  lon_dims[0]=nlon_dim;
  lon_dims[1]=nv_dim;
  time_dims[0]=time_dim;
  time_dims[1]=nv_dim;

  /* Define/write global attributes */
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "Conventions", strlen(conventions)+1, conventions)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "title", strlen(title)+1, title)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "source", strlen(source)+1, source)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "references", strlen(references)+1, references)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "history", strlen(history)+1, history)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "Metadata_Conventions", strlen(Metadata_Conventions)+1, Metadata_Conventions)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "standard_name_vocabulary", strlen(standard_name_vocabulary)+1, standard_name_vocabulary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "id", strlen(id)+1, id)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "naming_authority", strlen(naming_authority)+1, naming_authority)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "date_created", strlen(date_created)+1, date_created)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "license", strlen(license)+1, license)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "summary", strlen(summary)+1, summary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "keywords", strlen(keywords)+1, keywords)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "keywords_vocabulary", strlen(keywords_vocabulary)+1, keywords_vocabulary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdm_data_type", strlen(cdm_data_type)+1, cdm_data_type)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "project", strlen(project)+1, project)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "processing_level", strlen(processing_level)+1, processing_level)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "creator_name", strlen(creator_name)+1, creator_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "creator_email", strlen(creator_email)+1, creator_email)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "institution", strlen(institution)+1, institution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "publisher_name", strlen(publisher_name)+1, publisher_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "publisher_email", strlen(publisher_email)+1, publisher_email)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "publisher_url", strlen(publisher_url)+1, publisher_url)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_min", strlen(geospatial_lat_min)+1, geospatial_lat_min)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_max", strlen(geospatial_lat_max)+1, geospatial_lat_max)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_units", strlen(geospatial_lat_units)+1, geospatial_lat_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_resolution", strlen(geospatial_lat_resolution)+1, geospatial_lat_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_min", strlen(geospatial_lon_min)+1, geospatial_lon_min)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_max", strlen(geospatial_lon_max)+1, geospatial_lon_max)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_units", strlen(geospatial_lon_units)+1, geospatial_lon_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_resolution", strlen(geospatial_lon_resolution)+1, geospatial_lon_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_start", strlen(time_coverage_start)+1, time_coverage_start)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_end", strlen(time_coverage_end)+1, time_coverage_end)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_duration", strlen(time_coverage_duration)+1, time_coverage_duration)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "contributor_name", strlen(contributor_name)+1, contributor_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "contributor_role", strlen(contributor_role)+1, contributor_role)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "acknowledgment", strlen(acknowledgment)+1, acknowledgment)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdr_program", strlen(cdr_program)+1, cdr_program)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdr_variable", strlen(cdr_variable)+1, cdr_variable)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "metadata_link", strlen(metadata_link)+1, metadata_link)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "product_version", strlen(product_version)+1, product_version)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "platform", strlen(platform)+1, platform)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "sensor", strlen(sensor)+1, sensor)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "spatial_resolution", strlen(spatial_resolution)+1, spatial_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "comment", strlen(comment)+1, comment)) ERR(retval);



  /*********************************************************
   * Define variables and their attributes                 *
   *********************************************************/

  /* Latitude */
  if (retval = nc_def_var(ncid, "latitude", NC_FLOAT, 1, &nlat_dim, &latitude_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "long_name", strlen(latitude_longname)+1, latitude_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "standard_name", strlen(latitude_standard_name)+1, latitude_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "units", strlen(latitude_units)+1, latitude_units)) ERR(retval);
  if (retval = nc_put_att_float(ncid, latitude_var, "valid_range", NC_FLOAT, 2, latitude_valid_range)) ERR(retval);
//  if (retval = nc_put_att_float(ncid, latitude_var, "missing_value", NC_FLOAT, 1, &latitude_missing_value)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "axis", 2, "Y")) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "bounds", strlen(latitude_bounds)+1, latitude_bounds)) ERR(retval);

  /* Longitude */
  if (retval = nc_def_var(ncid, "longitude", NC_FLOAT, 1, &nlon_dim, &longitude_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "long_name", strlen(longitude_longname)+1, longitude_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "standard_name", strlen(longitude_standard_name)+1, longitude_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "units", strlen(longitude_units)+1, longitude_units)) ERR(retval);
  if (retval = nc_put_att_float(ncid, longitude_var, "valid_range", NC_FLOAT, 2, longitude_valid_range)) ERR(retval);
//  if (retval = nc_put_att_float(ncid, longitude_var, "missing_value", NC_FLOAT, 1, &longitude_missing_value)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "axis", 2, "X")) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "bounds", strlen(longitude_bounds)+1, longitude_bounds)) ERR(retval);

  /* Time */
  if (retval = nc_def_var(ncid, "time", NC_FLOAT, 1, &time_dim, &time_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "long_name", strlen(time_longname)+1, time_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "standard_name", strlen(time_standard_name)+1, time_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "units", strlen(time_units)+1, time_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "calendar", strlen(time_calendar)+1, time_calendar)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "axis", strlen(time_axis)+1, time_axis)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_var, "bounds", strlen("time_bounds")+1, "time_bounds")) ERR(retval);

  /* latitude_bounds */
  if (retval = nc_def_var(ncid, "lat_bounds", NC_FLOAT, 2, lat_dims, &lat_bounds_var)) ERR(retval);
//  if (retval = nc_put_att_text(ncid, lat_bounds_var, "units", strlen(lat_bounds_units)+1, lat_bounds_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, lat_bounds_var, "comment", strlen(lat_bounds_comment)+1, lat_bounds_comment)) ERR(retval);
  
  /* longitude_bounds */
  if (retval = nc_def_var(ncid, "lon_bounds", NC_FLOAT, 2, lon_dims, &lon_bounds_var)) ERR(retval);
//  if (retval = nc_put_att_text(ncid, lon_bounds_var, "units", strlen(lon_bounds_units)+1, lon_bounds_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, lon_bounds_var, "comment", strlen(lon_bounds_comment)+1, lon_bounds_comment)) ERR(retval);

   /* time_bounds */
  if (retval = nc_def_var(ncid, "time_bounds", NC_FLOAT, 2, time_dims, &time_bounds_var)) ERR(retval);
//  if (retval = nc_put_att_text(ncid, time_bounds_var, "units", strlen(time_bounds_units)+1, time_bounds_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, time_bounds_var, "comment", strlen(time_bounds_comment)+1, time_bounds_comment)) ERR(retval);

  /* precip */
  if (retval = nc_def_var(ncid, "precip", NC_FLOAT, 3, std_dims, &precip_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_var, "long_name", strlen(precip_longname)+1, precip_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_var, "standard_name", strlen(precip_standard_name)+1, precip_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_var, "units", strlen(precip_units)+1, precip_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_var, "coordinates", strlen(precip_coordinates)+1, precip_coordinates)) ERR(retval);
  if (retval = nc_put_att_float(ncid, precip_var, "valid_range", NC_FLOAT, 2, precip_valid_range)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_var, "cell_methods", strlen(precip_cell_methods)+1, precip_cell_methods)) ERR(retval);
  if (retval = nc_put_att_float(ncid, precip_var, "missing_value", NC_FLOAT, 1, &precip_missing_value)) ERR(retval);

  /* precip error */
  if (retval = nc_def_var(ncid, "precip_error", NC_FLOAT, 3, std_dims, &precip_error_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_error_var, "long_name", strlen(precip_error_longname)+1, precip_error_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_error_var, "units", strlen(precip_error_units)+1, precip_error_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, precip_error_var, "coordinates", strlen(precip_error_coordinates)+1, precip_error_coordinates)) ERR(retval);
  if (retval = nc_put_att_float(ncid, precip_error_var, "valid_range", NC_FLOAT, 2, precip_error_valid_range)) ERR(retval);
  if (retval = nc_put_att_float(ncid, precip_error_var, "missing_value", NC_FLOAT, 1, &precip_error_missing_value)) ERR(retval);



  /*********************************************************
   * End define mode: start writing data                   *
   *********************************************************/
  if (retval = nc_enddef(ncid)) ERR(retval);


  // Define latitudes and write to file
  for (i=0; i<72; i++) {
    lat_values[i]=-88.75+(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, latitude_var, &lat_values[0])) ERR(retval);
  
  // Define longitudes and write to file
  for (i=0; i<144; i++) {
    lon_values[i]=1.25+(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, longitude_var, &lon_values[0])) ERR(retval);

  // Define time and write to file
  time_bounds[0] = get_epoch_time(time_coverage_start);
  if (retval = nc_put_var_float(ncid, time_var, &time_bounds[0])) ERR(retval); 

  // Define latitude bounds

  for (i=0; i<72; i++) {
    lat_bounds[i][0] = -90.+(float)i*2.5;
    lat_bounds[i][1] = -87.5+(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, lat_bounds_var, &lat_bounds[0][0])) ERR(retval);

  // Define longitude bounds
  for (i=0; i<144; i++) {
    lon_bounds[i][0] = (float)i*2.5;
    lon_bounds[i][1] = 2.5+(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, lon_bounds_var, &lon_bounds[0][0])) ERR(retval);

  // Define time bounds - 0 got earlier
  time_bounds[1] = get_epoch_time(time_coverage_end);
  if (retval = nc_put_var_float(ncid, time_bounds_var, &time_bounds[0])) ERR(retval);
 
  // Read precip and add to netcdf file
  sprintf(fname_precip,"%s/bin/%04d/%02d/oc.%04d%02d.sg",OutputPATH,yyyy,mm,yyyy,mm);
  fp_precip=fopen(fname_precip,"r");
  if (fp_precip == NULL) {
    fprintf(stderr,"Can't open file: %s\n",fname_precip);
    exit(EXIT_FAILURE);
  }
  fread(&precip_values[0][0], sizeof(precip_values), 144*72, fp_precip);
  fclose(fp_precip);
  for (i=0; i<72; i++) {
  for (j=0; j<144; j++){
    precip_values_rev[i][j]=precip_values[71-i][j];
  }
  }
  if (retval = nc_put_var_float(ncid, precip_var, &precip_values_rev[0][0])) ERR(retval);

  // Read precip error and add to netcdf file

  sprintf(fname_precip_error,"%s/bin/%04d/%02d/oc.%04d%02d.esg",OutputPATH,yyyy,mm,yyyy,mm);
  fp_precip_error=fopen(fname_precip_error,"r");
  if (fp_precip_error == NULL) {
    fprintf(stderr,"Can't open file: %s\n",fname_precip_error);
    exit(EXIT_FAILURE);
  }
  fread(&precip_error_values[0][0], sizeof(precip_error_values), 144*72, fp_precip_error);
  fclose(fp_precip_error);
  for (i=0; i<72; i++) {
  for (j=0; j<144; j++){
    precip_error_values_rev[i][j]=precip_error_values[71-i][j];
  }
  }
  if (retval = nc_put_var_float(ncid, precip_error_var, &precip_error_values_rev[0][0])) ERR(retval);


  /* Close netcdf file */
  if ((retval = nc_close(ncid))) ERR(retval);


}
