#include <stdio.h>
#include <netcdf.h>
#include <string.h>
#include <stdlib.h>

/* Required for error checking reading NetCDF files */
#define ERR(e) {fprintf(stderr,"Error (CDR Write): %s\n", nc_strerror(e)); return ;;}
#include "../../OptionsM.h"



/* The following table lists the data that is output to the interim NetCDF file
 * The three digit code is the GPCP name, the filename is the name used internally 
 * in the code (these names are unchanged from the original code for traceability).
 * There are three different data periods:
 *  1  Jan 79 to Dec 85
 *  2  Jan 86 to jul 87 (plus dec 87)
 *  3  Aug 87-present (excl dec 87)
 * 
 * pop   oc.YYYYMM.adge    1    Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate
 * pms   oc.YYYYMM.s       123  Multi-satellite precipitation
 * pga   oc.YYYYMM.corg    123  Gauge precipitation
 * psg   oc.YYYYMM.sg      123  Satellite/gauge precipitation
 * eop   oc.YYYYMM.egeo    1    Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation random error
 * ems   oc.YYYYMM.es      123  Multi-satellite precipitation random error
 * ega   oc.YYYYMM.ega     123  Gauge precipitation random error
 * esg   oc.YYYYMM.esg     123  Satellite/gauge precipitation random error
 * nga   oc.YYYYMM.nga     123  Gauge precipitation number of gauges
 * pag   oc.YYYYMM.adge     23  Adjusted GOES Precipitation Index (AGPI) precipitation estimate
 * eag   oc.YYYYMM.egeo     23  Adjusted GOES Precipitation Index (AGPI) precipitation random error
 * pop   opi.YYYYMM.rssfix  2   Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate
 * pgp   oc.YYYYMM.pgp      23  GOES Precipitation Index (GPI) precipitation estimate
 * ngp   oc.YYYYMM.ngp      23  GOES Precipitation Index (GPI) image number
 * pse   cg.YYYYMM.rcfull    3  SSM/I emission precipitation estimate
 * nse   cg.YYYYMM.Icfull    3  SSM/I emission precipitation number of samples
 * pss   cg.YYYYMM.rgfull    3  SSM/I scattering precipitation estimate
 * nss   cg.YYYYMM.Igfull    3  SSM/I scattering precipitation number of samples
 * psc   cg.YYYYMM.rfix      3  SSM/I composite precipitation estimate
 * ssc   cg.YYYYMM.src       3  SSM/I composite precipitation source
 * nsc   cg.YYYYMM.Ifix      3  SSM/I composite precipitation number of samples
 * pst   cgt.YYYYMM.rfix     3  Merged SSMI/TOVS precipitation estimate
 * est   oc.YYYYMM.ess       3  Merged SSMI/TOVS precipitation random error
 * sst   cgt.YYYYMM.src      3  Merged SSMI/TOVS precipitation source
 * ptv   cgt.YYYYMM.tovs     3  TOVS precipitation estimate
 */



int Write_Interim_nc(char *dirname, char *filename, char *VersNum, char *CompName, char *current_time_str, int yyyy, int mm)
{
  int     i, oflag;
  int     ncid;   /* Netcdf file unit */
  int     retval; /* Status flag for netcdf files */
  int     yyyymm;
  FILE   *fopen();
  FILE   *fp_precip;
  FILE   *fp_precip_error;
  char    fname_precip[256];
  char    fname_precip_error[256];
  char   *yyyy_mm_dd;
  char    fname[512];
  char    tmpchar1[256], tmpchar2[256];
  char    tmpcomma[2];
  int     Ndays[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
  int     LeapYear;

  // Dimension ids
  int     std_dims[2];
  int     nlat_dim;
  int     nlon_dim;

  // Variable ids
  int     latitude_var;
  int     longitude_var;
  int     pop_var;
  int     pms_var;
  int     pga_var;
  int     psg_var;
  int     eop_var;
  int     ems_var;
  int     ega_var;
  int     esg_var;
  int     nga_var;
  int     pag_var;
  int     eag_var;
  int     pgp_var;
  int     ngp_var;
  int     pse_var;
  int     nse_var;
  int     pss_var;
  int     nss_var;
  int     psc_var;
  int     ssc_var;
  int     nsc_var;
  int     pst_var;
  int     est_var;
  int     sst_var;
  int     ptv_var;


  // Static global attributes
  char    conventions[]               = "CF-1.5";
  char    title[]                     = "GPCP V2.2 Satellite-Gauge Precipitation Climate Data Record";
  char    references[]                = "Huffman et al. 1997, http://dx.doi.org/10.1175/1520-0477(1997)078<0005:TGPCPG>2.0.CO;2; Adler et al. 2003, http://dx.doi.org/10.1175/1525-7541(2003)004<1147:TVGPCP>2.0.CO;2; Huffman et al. 2009, http://dx.doi.org/10.1029/2009GL040000";
  char    Metadata_Conventions[]      = "CF-1.5, Unidata Dataset Discovery v1.0, NOAA CDR v1.0, GDS v2.0";
  char    standard_name_vocabulary[]  = "CF Standard Name Table (v16, 11 October 2010)";
  char    naming_authority[]          = "gov.noaa.ncdc";
  char    license[]                   = "No constraints on data access or use.";
  char    summary[]                   = "Global Precipitation Climatology Project (GPCP) Version 2.2 gridded, merged satellite/gauge precipitation Climate data Record (CDR) with errors from 1979 to present.";
  char    keywords[]                  = "EARTH SCIENCE > ATMOSPHERE > PRECIPITATION > PRECIPITATION AMOUNT";
  char    keywords_vocabulary[]       = "NASA Global Change Master Directory (GCMD) Earth Science Keywords, Version 7.0";
  char    cdm_data_type[]             = "Grid";
  char    project[]                   = "GPCP > Global Precipitation Climatology Project";
  char    processing_level[]          = "NASA Level 3";
  char    creator_name[]              = "Dr. Robert F. Adler";
  char    creator_email[]             = "radler@umd.edu";
  char    institution[]               = "ACADEMIC > UMD/ESSIC > Earth System Science Interdisciplinary Center, University of Maryland";
  char    geospatial_lat_min[]        = "-88.75";
  char    geospatial_lat_max[]        = "88.75";
  char    geospatial_lat_units[]      = "degrees_north";
  char    geospatial_lat_resolution[] = "2.5 degrees";
  char    geospatial_lon_min[]        = "1.25";
  char    geospatial_lon_max[]        = "358.75";
  char    geospatial_lon_units[]      = "degrees_east";
  char    geospatial_lon_resolution[] = "2.5 degrees";
  char    time_coverage_duration[]    = "P1M";
  char    contributor_name[]          = "Robert Adler, George Huffman, Mathew Sapiano";
  char    contributor_role[]          = "principalInvestigator, principalInvestigator, processor and custodian";
  char    acknowledgment[]            = "This project was supported in part by a grant from the NOAA Climate Data Record (CDR) Program for satellites.";
  char    cdr_program[]               = "NOAA Climate Data Record Program for satellites, FY 2011.";
  char    cdr_variable[]              = "precipitation";
  char    metadata_link[]             = "gov.noaa.ncdc:XXXXX";
  char    spatial_resolution[]        = "2.5 degree";

  // variable global attributes
  char    source[256];
  char    history[256];
  char    id[256];
  char    date_created[256];
  char    time_coverage_start[256];
  char    time_coverage_end[256];
  char    product_version[256];
  char    platform[1000];
  char    sensor[1000];
  char    comment[2000];

  // Attributes for each variable
  char    latitude_longname[]      ="Latitude";
  char    latitude_standard_name[] ="latitude" ;
  char    latitude_units[]         ="degrees_north" ;
  float   latitude_valid_range[2]  ={-90.,90.};
  float   latitude_missing_value   =-9999.;

  char    longitude_longname[]      ="Longitude";
  char    longitude_standard_name[] ="longitude" ;
  char    longitude_units[]         ="degrees_east" ;
  float   longitude_valid_range[2]  ={-180.,180.};
  float   longitude_missing_value   =-9999.;

  FILE   *fp_pop;
  char    fname_pop[256];
  char    pop_longname[]      ="NOAA CDR of GPCP Interim product: Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate";
  char    pop_units[]         ="millimeters/day" ;
  char    pop_coordinates[]   ="longitude latitude" ;
  float   pop_valid_range[2]  ={0.,100.};
  float   pop_missing_value   =-9999.;

  FILE   *fp_pms;
  char    fname_pms[256];
  char    pms_longname[]      ="NOAA CDR of GPCP Interim product: Multi-satellite precipitation";
  char    pms_units[]         ="millimeters/day" ;
  char    pms_coordinates[]   ="longitude latitude" ;
  float   pms_valid_range[2]  ={0.,100.};
  float   pms_missing_value   =-9999.;

  FILE   *fp_pga;
  char    fname_pga[256];
  char    pga_longname[]      ="NOAA CDR of GPCP Interim product: Gauge precipitation";
  char    pga_units[]         ="millimeters/day" ;
  char    pga_coordinates[]   ="longitude latitude" ;
  float   pga_valid_range[2]  ={0.,100.};
  float   pga_missing_value   =-9999.;

  FILE   *fp_psg;
  char    fname_psg[256];
  char    psg_longname[]      ="NOAA CDR of GPCP Interim product: Satellite/gauge precipitation";
  char    psg_units[]         ="millimeters/day" ;
  char    psg_coordinates[]   ="longitude latitude" ;
  float   psg_valid_range[2]  ={0.,100.};
  float   psg_missing_value   =-9999.;

  FILE   *fp_eop;
  char    fname_eop[256];
  char    eop_longname[]      ="NOAA CDR of GPCP Interim product: Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation random error";
  char    eop_units[]         ="millimeters/day" ;
  char    eop_coordinates[]   ="longitude latitude" ;
  float   eop_valid_range[2]  ={0.,100.};
  float   eop_missing_value   =-9999.;

  FILE   *fp_ems;
  char    fname_ems[256];
  char    ems_longname[]      ="NOAA CDR of GPCP Interim product: Multi-satellite precipitation random error";
  char    ems_units[]         ="millimeters/day" ;
  char    ems_coordinates[]   ="longitude latitude" ;
  float   ems_valid_range[2]  ={0.,100.};
  float   ems_missing_value   =-9999.;

  FILE   *fp_ega;
  char    fname_ega[256];
  char    ega_longname[]      ="NOAA CDR of GPCP Interim product: Gauge precipitation random error";
  char    ega_units[]         ="millimeters/day" ;
  char    ega_coordinates[]   ="longitude latitude" ;
  float   ega_valid_range[2]  ={0.,100.};
  float   ega_missing_value   =-9999.;

  FILE   *fp_esg;
  char    fname_esg[256];
  char    esg_longname[]      ="NOAA CDR of GPCP Interim product: Satellite/gauge precipitation random error";
  char    esg_units[]         ="millimeters/day" ;
  char    esg_coordinates[]   ="longitude latitude" ;
  float   esg_valid_range[2]  ={0.,100.};
  float   esg_missing_value   =-9999.;

  FILE   *fp_nga;
  char    fname_nga[256];
  char    nga_longname[]      ="NOAA CDR of GPCP Interim product: Gauge precipitation number of gauges";
  char    nga_units[]         ="" ;
  char    nga_coordinates[]   ="longitude latitude" ;
  float   nga_valid_range[2]  ={0.,100.};
  float   nga_missing_value   =-9999.;

  FILE   *fp_pag;
  char    fname_pag[256];
  char    pag_longname[]      ="NOAA CDR of GPCP Interim product: Adjusted GOES Precipitation Index (AGPI) precipitation estimate";
  char    pag_units[]         ="millimeters/day" ;
  char    pag_coordinates[]   ="longitude latitude" ;
  float   pag_valid_range[2]  ={0.,100.};
  float   pag_missing_value   =-9999.;

  FILE   *fp_eag;
  char    fname_eag[256];
  char    eag_longname[]      ="NOAA CDR of GPCP Interim product: Adjusted GOES Precipitation Index (AGPI) precipitation random error";
  char    eag_units[]         ="millimeters/day" ;
  char    eag_coordinates[]   ="longitude latitude" ;
  float   eag_valid_range[2]  ={0.,100.};
  float   eag_missing_value   =-9999.;

  FILE   *fp_pgp;
  char    fname_pgp[256];
  char    pgp_longname[]      ="NOAA CDR of GPCP Interim product: GOES Precipitation Index (GPI) precipitation estimate";
  char    pgp_units[]         ="millimeters/day" ;
  char    pgp_coordinates[]   ="longitude latitude" ;
  float   pgp_valid_range[2]  ={0.,100.};
  float   pgp_missing_value   =-9999.;

  FILE   *fp_ngp;
  char    fname_ngp[256];
  char    ngp_longname[]      ="NOAA CDR of GPCP Interim product: GOES Precipitation Index (GPI) image number";
  char    ngp_units[]         ="" ;
  char    ngp_coordinates[]   ="longitude latitude" ;
  float   ngp_valid_range[2]  ={0.,100.};
  float   ngp_missing_value   =-9999.;

  FILE   *fp_pse;
  char    fname_pse[256];
  char    pse_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I emission precipitation estimate";
  char    pse_units[]         ="millimeters/day" ;
  char    pse_coordinates[]   ="longitude latitude" ;
  float   pse_valid_range[2]  ={0.,100.};
  float   pse_missing_value   =-9999.;

  FILE   *fp_nse;
  char    fname_nse[256];
  char    nse_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I emission precipitation number of samples";
  char    nse_units[]         ="";
  char    nse_coordinates[]   ="longitude latitude" ;
  float   nse_valid_range[2]  ={0.,100.};
  float   nse_missing_value   =-9999.;

  FILE   *fp_pss;
  char    fname_pss[256];
  char    pss_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I scattering precipitation estimate";
  char    pss_units[]         ="millimeters/day" ;
  char    pss_coordinates[]   ="longitude latitude" ;
  float   pss_valid_range[2]  ={0.,100.};
  float   pss_missing_value   =-9999.;

  FILE   *fp_nss;
  char    fname_nss[256];
  char    nss_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I scattering precipitation number of samples";
  char    nss_units[]         ="" ;
  char    nss_coordinates[]   ="longitude latitude" ;
  float   nss_valid_range[2]  ={0.,100.};
  float   nss_missing_value   =-9999.;

  FILE   *fp_psc;
  char    fname_psc[256];
  char    psc_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I composite precipitation estimate";
  char    psc_units[]         ="millimeters/day" ;
  char    psc_coordinates[]   ="longitude latitude" ;
  float   psc_valid_range[2]  ={0.,100.};
  float   psc_missing_value   =-9999.;

  FILE   *fp_ssc;
  char    fname_ssc[256];
  char    ssc_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I composite precipitation source";
  char    ssc_units[]         ="" ;
  char    ssc_coordinates[]   ="longitude latitude" ;
  float   ssc_valid_range[2]  ={0.,100.};
  float   ssc_missing_value   =-9999.;

  FILE   *fp_nsc;
  char    fname_nsc[256];
  char    nsc_longname[]      ="NOAA CDR of GPCP Interim product: SSM/I composite precipitation number of samples";
  char    nsc_units[]         ="" ;
  char    nsc_coordinates[]   ="longitude latitude" ;
  float   nsc_valid_range[2]  ={0.,100.};
  float   nsc_missing_value   =-9999.;

  FILE   *fp_pst;
  char    fname_pst[256];
  char    pst_longname[]      ="NOAA CDR of GPCP Interim product: Merged SSMI/TOVS precipitation estimate";
  char    pst_units[]         ="millimeters/day" ;
  char    pst_coordinates[]   ="longitude latitude" ;
  float   pst_valid_range[2]  ={0.,100.};
  float   pst_missing_value   =-9999.;

  FILE   *fp_est;
  char    fname_est[256];
  char    est_longname[]      ="NOAA CDR of GPCP Interim product: Merged SSMI/TOVS precipitation random error";
  char    est_units[]         ="millimeters/day" ;
  char    est_coordinates[]   ="longitude latitude" ;
  float   est_valid_range[2]  ={0.,100.};
  float   est_missing_value   =-9999.;

  FILE   *fp_sst;
  char    fname_sst[256];
  char    sst_longname[]      ="NOAA CDR of GPCP Interim product: Merged SSMI/TOVS precipitation source";
  char    sst_units[]         ="" ;
  char    sst_coordinates[]   ="longitude latitude" ;
  float   sst_valid_range[2]  ={0.,100.};
  float   sst_missing_value   =-9999.;

  FILE   *fp_ptv;
  char    fname_ptv[256];
  char    ptv_longname[]      ="NOAA CDR of GPCP Interim product: TOVS precipitation estimate";
  char    ptv_units[]         ="millimeters/day" ;
  char    ptv_coordinates[]   ="longitude latitude" ;
  float   ptv_valid_range[2]  ={0.,100.};
  float   ptv_missing_value   =-9999.;


  // Define fields to hold actual data values
  float   lat_values[72];
  float   lon_values[144];
  float   pop_values[72][144];
  float   pms_values[72][144];
  float   pga_values[72][144];
  float   psg_values[72][144];
  float   eop_values[72][144];
  float   ems_values[72][144];
  float   ega_values[72][144];
  float   esg_values[72][144];
  float   nga_values[72][144];
  float   pag_values[72][144];
  float   eag_values[72][144];
  float   pgp_values[72][144];
  float   ngp_values[72][144];
  float   pse_values[72][144];
  float   nse_values[72][144];
  float   pss_values[72][144];
  float   nss_values[72][144];
  float   psc_values[72][144];
  float   ssc_values[72][144];
  float   nsc_values[72][144];
  float   pst_values[72][144];
  float   est_values[72][144];
  float   sst_values[72][144];
  float   ptv_values[72][144];



										      
  /********************************************************* 
   * Set values of variable global attributes              *
   *********************************************************/

  // Product version
  sprintf(product_version,"%s",VersNum);

  // History
  memcpy(&yyyy_mm_dd, &current_time_str, 10);
  sprintf(history, "1) %s, Mathew Sapiano, U of Maryland, Created beta (B1) file",yyyy_mm_dd);

  // ID
  sprintf(id,"%s",filename);

  // Date created
  sprintf(date_created,"%s",current_time_str);

  //Time coverage start/end
  if ( (mm == 2) && (yyyy % 4 == 0) && (yyyy != 2000)) {
    LeapYear=1;
  }
  else {
    LeapYear=0;
  }
  sprintf(time_coverage_start,"%04d-%02d-01T00:00:00Z",yyyy,mm);
  sprintf(time_coverage_end,"%04d-%02d-%02dT23:59:59Z",yyyy,mm,Ndays[mm-1]+LeapYear);

  // Processing computer (comment)
  sprintf(comment,"Processing computer: %s",CompName);

  // epoch based data - depends on month and year
  yyyymm=100*yyyy+mm;
  strcpy(tmpcomma,"");
  strcpy(platform,"");

  // Add AVHRR to platform and sensor global attributes
  if (yyyymm >= 197901 & yyyymm <= 198512){
    sprintf(tmpchar1,"%s%sNOAA POES (Polar Orbiting Environmental Satellites)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sAVHRR>Advanced Very High Resolution Radiometer",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  // Add Geo-IR to platform and sensor global attributes
  if (yyyymm >= 198601){
    sprintf(tmpchar1,"%s%sGOES (Geostationary Operational Environmental Satellite), GMS (Japan Geostationary Meteorological Satellite), METEOSAT",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sImager, Imager, Imager",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  // Add TOVS to platform and sensor global attributes
  if ((yyyymm >= 198707 & yyyymm <= 200503) & (yyyymm != 200402) & (yyyymm != 198712)) {
    sprintf(tmpchar1,"%s%sTIROS > Television Infrared Observation Satellite",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sTOVS > TIROS Operational Vertical Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  // Add AIRS to platform and sensor global attributes
  if ((yyyymm >= 200504) | (yyyymm == 200402)) {
    sprintf(tmpchar1,"%s%sEarth Observing System, AQUA",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sAIRS > Atmospheric Infrared Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  // Add SSMI to platform and sensor global attributes
  if ((yyyymm >= 198707 & yyyymm <= 200812) & (yyyymm != 198712)){
    sprintf(tmpchar1,"%s%sDMSP (Defense Meteorological Satellite Program)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sSSMI > Special Sensor Microwave/Imager",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  // Add SSMIS to platform and sensor global attributes
  if (yyyymm >= 200901) {
    sprintf(tmpchar1,"%s%sDMSP (Defense Meteorological Satellite Program)",platform,tmpcomma);
    sprintf(tmpchar2,"%s%sSSMIS > Special Sensor Microwave Imager/Sounder",sensor,tmpcomma);
    strcpy(platform,tmpchar1);
    strcpy(sensor,tmpchar2);
    strcpy(tmpcomma,", ");
  }

  

  /****************************************************************************
   * Set Source and output flag for GlobAtt and set flags for output values   *
   * Source is actually static for the CDR file, but dynamic for the interim  */
  oflag=0;

  // OPI period Jan 79 to Dec 85
  if (yyyymm >= 197901 & yyyymm <= 198512){
    oflag=1;
    sprintf(source,"%s","oc.YYYYMM.adge, oc.YYYYMM.s, oc.YYYYMM.corg, oc.YYYYMM.sg, oc.YYYYMM.egeo, oc.YYYYMM.es, oc.YYYYMM.ega, oc.YYYYMM.esg, oc.YYYYMM.nga");
  }
  // Pre-SSMI period: Jan 86 to jul 87 (plus dec 87)
  if ((yyyymm >= 198601 & yyyymm <= 198707) | (yyyymm == 198712)) {
    oflag=2;
    sprintf(source,"%s","oc.YYYYMM.s, oc.YYYYMM.corg, oc.YYYYMM.sg, oc.YYYYMM.egeo, oc.YYYYMM.es, oc.YYYYMM.ega, oc.YYYYMM.esg, oc.YYYYMM.nga, oc.YYYYMM.adge, oc.YYYYMM.egeo, opi.YYYYMM.rssfix, oc.YYYYMM.pgp, oc.YYYYMM.ngp");
  }
  // SSMI/SSMIS/TOVS/AIRS period: Aug 87-present (excl dec 87)
  if (yyyymm >= 198708 & yyyymm != 198712) {
    oflag=3;
    sprintf(source,"%s","oc.YYYYMM.s, oc.YYYYMM.corg, oc.YYYYMM.sg, oc.YYYYMM.es, oc.YYYYMM.ega, oc.YYYYMM.esg, oc.YYYYMM.nga, oc.YYYYMM.adge, oc.YYYYMM.egeo, oc.YYYYMM.pgp, oc.YYYYMM.ngp, cg.YYYYMM.rcfull, cg.YYYYMM.Icfull, cg.YYYYMM.rgfull, cg.YYYYMM.Igfull, cg.YYYYMM.rfix, cg.YYYYMM.src, cg.YYYYMM.Ifix, cgt.YYYYMM.rfix, oc.YYYYMM.ess, cgt.YYYYMM.src, cgt.YYYYMM.tovs");
  }




  /*********************************************************
   * Start writing to file                                 *
   * The file is opened in define mode                     *
   *********************************************************/
  
  /* Open NetCDF file */
  sprintf(fname,"%s%s",dirname, filename);
  if (retval = nc_create(fname, NC_NETCDF4|NC_SHARE, &ncid)) ERR(retval);

  /* Define/write dimensions and dimid */
  if (retval = nc_def_dim(ncid, "nlat", 72, &nlat_dim)) ERR(retval);
  if (retval = nc_def_dim(ncid, "nlon", 144, &nlon_dim)) ERR(retval);
  std_dims[0]=nlat_dim;
  std_dims[1]=nlon_dim;

  /* Define/write global attributes */
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "Conventions", strlen(conventions)+1, conventions)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "title", strlen(title)+1, title)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "source", strlen(source)+1, source)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "references", strlen(references)+1, references)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "history", strlen(history)+1, history)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "Metadata_Conventions", strlen(Metadata_Conventions)+1, Metadata_Conventions)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "standard_name_vocabulary", strlen(standard_name_vocabulary)+1, standard_name_vocabulary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "id", strlen(id)+1, id)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "naming_authority", strlen(naming_authority)+1, naming_authority)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "date_created", strlen(date_created)+1, date_created)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "license", strlen(license)+1, license)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "summary", strlen(summary)+1, summary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "keywords", strlen(keywords)+1, keywords)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "keywords_vocabulary", strlen(keywords_vocabulary)+1, keywords_vocabulary)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdm_data_type", strlen(cdm_data_type)+1, cdm_data_type)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "project", strlen(project)+1, project)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "processing_level", strlen(processing_level)+1, processing_level)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "creator_name", strlen(creator_name)+1, creator_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "creator_email", strlen(creator_email)+1, creator_email)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "institution", strlen(institution)+1, institution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_min", strlen(geospatial_lat_min)+1, geospatial_lat_min)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_max", strlen(geospatial_lat_max)+1, geospatial_lat_max)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_units", strlen(geospatial_lat_units)+1, geospatial_lat_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lat_resolution", strlen(geospatial_lat_resolution)+1, geospatial_lat_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_min", strlen(geospatial_lon_min)+1, geospatial_lon_min)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_max", strlen(geospatial_lon_max)+1, geospatial_lon_max)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_units", strlen(geospatial_lon_units)+1, geospatial_lon_units)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "geospatial_lon_resolution", strlen(geospatial_lon_resolution)+1, geospatial_lon_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_start", strlen(time_coverage_start)+1, time_coverage_start)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_end", strlen(time_coverage_end)+1, time_coverage_end)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "time_coverage_duration", strlen(time_coverage_duration)+1, time_coverage_duration)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "contributor_name", strlen(contributor_name)+1, contributor_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "contributor_role", strlen(contributor_role)+1, contributor_role)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "acknowledgment", strlen(acknowledgment)+1, acknowledgment)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdr_program", strlen(cdr_program)+1, cdr_program)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "cdr_variable", strlen(cdr_variable)+1, cdr_variable)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "metadata_link", strlen(metadata_link)+1, metadata_link)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "product_version", strlen(product_version)+1, product_version)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "platform", strlen(platform)+1, platform)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "sensor", strlen(sensor)+1, sensor)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "spatial_resolution", strlen(spatial_resolution)+1, spatial_resolution)) ERR(retval);
  if (retval = nc_put_att_text(ncid, NC_GLOBAL, "comment", strlen(comment)+1, comment)) ERR(retval);



  /*********************************************************
   * Define variables and their attributes                 *
   *********************************************************/

  /* Latitude */
  if (retval = nc_def_var(ncid, "latitude", NC_FLOAT, 1, &nlat_dim, &latitude_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "long_name", strlen(latitude_longname)+1, latitude_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "standard_name", strlen(latitude_standard_name)+1, latitude_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, latitude_var, "units", strlen(latitude_units)+1, latitude_units)) ERR(retval);
  if (retval = nc_put_att_float(ncid, latitude_var, "valid_range", NC_FLOAT, 2, latitude_valid_range)) ERR(retval);
  if (retval = nc_put_att_float(ncid, latitude_var, "missing_value", NC_FLOAT, 1, &latitude_missing_value)) ERR(retval);

  /* Longitude */
  if (retval = nc_def_var(ncid, "longitude", NC_FLOAT, 1, &nlon_dim, &longitude_var)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "long_name", strlen(longitude_longname)+1, longitude_longname)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "standard_name", strlen(longitude_standard_name)+1, longitude_standard_name)) ERR(retval);
  if (retval = nc_put_att_text(ncid, longitude_var, "units", strlen(longitude_units)+1, longitude_units)) ERR(retval);
  if (retval = nc_put_att_float(ncid, longitude_var, "valid_range", NC_FLOAT, 2, longitude_valid_range)) ERR(retval);
  if (retval = nc_put_att_float(ncid, longitude_var, "missing_value", NC_FLOAT, 1, &longitude_missing_value)) ERR(retval);

  /* Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate */
  if (oflag==1) {
    if (retval = nc_def_var(ncid, "pop", NC_FLOAT, 2, std_dims, &pop_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "long_name", strlen(pop_longname)+1, pop_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "units", strlen(pop_units)+1, pop_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "coordinates", strlen(pop_coordinates)+1, pop_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pop_var, "valid_range", NC_FLOAT, 2, pop_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pop_var, "missing_value", NC_FLOAT, 1, &pop_missing_value)) ERR(retval);
  }

  /* Multi-satellite precipitation */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "pms", NC_FLOAT, 2, std_dims, &pms_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pms_var, "long_name", strlen(pms_longname)+1, pms_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pms_var, "units", strlen(pms_units)+1, pms_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pms_var, "coordinates", strlen(pms_coordinates)+1, pms_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pms_var, "valid_range", NC_FLOAT, 2, pms_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pms_var, "missing_value", NC_FLOAT, 1, &pms_missing_value)) ERR(retval);
  }

  /* Gauge precipitation */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "pga", NC_FLOAT, 2, std_dims, &pga_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pga_var, "long_name", strlen(pga_longname)+1, pga_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pga_var, "units", strlen(pga_units)+1, pga_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pga_var, "coordinates", strlen(pga_coordinates)+1, pga_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pga_var, "valid_range", NC_FLOAT, 2, pga_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pga_var, "missing_value", NC_FLOAT, 1, &pga_missing_value)) ERR(retval);
  }

  /* Satellite/gauge precipitation */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "psg", NC_FLOAT, 2, std_dims, &psg_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psg_var, "long_name", strlen(psg_longname)+1, psg_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psg_var, "units", strlen(psg_units)+1, psg_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psg_var, "coordinates", strlen(psg_coordinates)+1, psg_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, psg_var, "valid_range", NC_FLOAT, 2, psg_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, psg_var, "missing_value", NC_FLOAT, 1, &psg_missing_value)) ERR(retval);
  }

  /* Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation random error */
  if (oflag==1) {
    if (retval = nc_def_var(ncid, "eop", NC_FLOAT, 2, std_dims, &eop_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eop_var, "long_name", strlen(eop_longname)+1, eop_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eop_var, "units", strlen(eop_units)+1, eop_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eop_var, "coordinates", strlen(eop_coordinates)+1, eop_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, eop_var, "valid_range", NC_FLOAT, 2, eop_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, eop_var, "missing_value", NC_FLOAT, 1, &eop_missing_value)) ERR(retval);
  }

  /* Multi-satellite precipitation random error */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "ems", NC_FLOAT, 2, std_dims, &ems_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ems_var, "long_name", strlen(ems_longname)+1, ems_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ems_var, "units", strlen(ems_units)+1, ems_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ems_var, "coordinates", strlen(ems_coordinates)+1, ems_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ems_var, "valid_range", NC_FLOAT, 2, ems_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ems_var, "missing_value", NC_FLOAT, 1, &ems_missing_value)) ERR(retval);
  }

  /* Gauge precipitation random error */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "ega", NC_FLOAT, 2, std_dims, &ega_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ega_var, "long_name", strlen(ega_longname)+1, ega_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ega_var, "units", strlen(ega_units)+1, ega_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ega_var, "coordinates", strlen(ega_coordinates)+1, ega_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ega_var, "valid_range", NC_FLOAT, 2, ega_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ega_var, "missing_value", NC_FLOAT, 1, &ega_missing_value)) ERR(retval);
  }

  /* Satellite/gauge precipitation random error */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "esg", NC_FLOAT, 2, std_dims, &esg_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, esg_var, "long_name", strlen(esg_longname)+1, esg_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, esg_var, "units", strlen(esg_units)+1, esg_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, esg_var, "coordinates", strlen(esg_coordinates)+1, esg_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, esg_var, "valid_range", NC_FLOAT, 2, esg_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, esg_var, "missing_value", NC_FLOAT, 1, &esg_missing_value)) ERR(retval);
  }

  /* Gauge precipitation number of gauges */
  if (oflag==1 | oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "nga", NC_FLOAT, 2, std_dims, &nga_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nga_var, "long_name", strlen(nga_longname)+1, nga_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nga_var, "units", strlen(nga_units)+1, nga_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nga_var, "coordinates", strlen(nga_coordinates)+1, nga_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nga_var, "valid_range", NC_FLOAT, 2, nga_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nga_var, "missing_value", NC_FLOAT, 1, &nga_missing_value)) ERR(retval);
  }

  /* Adjusted GOES Precipitation Index (AGPI) precipitation estimate */
  if (oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "pag", NC_FLOAT, 2, std_dims, &pag_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pag_var, "long_name", strlen(pag_longname)+1, pag_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pag_var, "units", strlen(pag_units)+1, pag_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pag_var, "coordinates", strlen(pag_coordinates)+1, pag_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pag_var, "valid_range", NC_FLOAT, 2, pag_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pag_var, "missing_value", NC_FLOAT, 1, &pag_missing_value)) ERR(retval);
  }

  /* Adjusted GOES Precipitation Index (AGPI) precipitation random error */
  if (oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "eag", NC_FLOAT, 2, std_dims, &eag_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eag_var, "long_name", strlen(eag_longname)+1, eag_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eag_var, "units", strlen(eag_units)+1, eag_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, eag_var, "coordinates", strlen(eag_coordinates)+1, eag_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, eag_var, "valid_range", NC_FLOAT, 2, eag_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, eag_var, "missing_value", NC_FLOAT, 1, &eag_missing_value)) ERR(retval);
  }

  /* Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate */
  if (oflag==2) {
    if (retval = nc_def_var(ncid, "pop", NC_FLOAT, 2, std_dims, &pop_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "long_name", strlen(pop_longname)+1, pop_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "units", strlen(pop_units)+1, pop_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pop_var, "coordinates", strlen(pop_coordinates)+1, pop_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pop_var, "valid_range", NC_FLOAT, 2, pop_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pop_var, "missing_value", NC_FLOAT, 1, &pop_missing_value)) ERR(retval);
  }

  /* GOES Precipitation Index (GPI) precipitation estimate */
  if (oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "pgp", NC_FLOAT, 2, std_dims, &pgp_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pgp_var, "long_name", strlen(pgp_longname)+1, pgp_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pgp_var, "units", strlen(pgp_units)+1, pgp_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pgp_var, "coordinates", strlen(pgp_coordinates)+1, pgp_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pgp_var, "valid_range", NC_FLOAT, 2, pgp_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pgp_var, "missing_value", NC_FLOAT, 1, &pgp_missing_value)) ERR(retval);
  }

  /* GOES Precipitation Index (GPI) image number */
  if (oflag==2 | oflag==3) {
    if (retval = nc_def_var(ncid, "ngp", NC_FLOAT, 2, std_dims, &ngp_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ngp_var, "long_name", strlen(ngp_longname)+1, ngp_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ngp_var, "units", strlen(ngp_units)+1, ngp_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ngp_var, "coordinates", strlen(ngp_coordinates)+1, ngp_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ngp_var, "valid_range", NC_FLOAT, 2, ngp_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ngp_var, "missing_value", NC_FLOAT, 1, &ngp_missing_value)) ERR(retval);
  }

  /* SSM/I emission precipitation estimate */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "pse", NC_FLOAT, 2, std_dims, &pse_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pse_var, "long_name", strlen(pse_longname)+1, pse_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pse_var, "units", strlen(pse_units)+1, pse_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pse_var, "coordinates", strlen(pse_coordinates)+1, pse_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pse_var, "valid_range", NC_FLOAT, 2, pse_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pse_var, "missing_value", NC_FLOAT, 1, &pse_missing_value)) ERR(retval);
  }

  /* SSM/I emission precipitation number of samples */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "nse", NC_FLOAT, 2, std_dims, &nse_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nse_var, "long_name", strlen(nse_longname)+1, nse_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nse_var, "units", strlen(nse_units)+1, nse_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nse_var, "coordinates", strlen(nse_coordinates)+1, nse_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nse_var, "valid_range", NC_FLOAT, 2, nse_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nse_var, "missing_value", NC_FLOAT, 1, &nse_missing_value)) ERR(retval);
  }

  /* SSM/I scattering precipitation estimate */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "pss", NC_FLOAT, 2, std_dims, &pss_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pss_var, "long_name", strlen(pss_longname)+1, pss_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pss_var, "units", strlen(pss_units)+1, pss_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pss_var, "coordinates", strlen(pss_coordinates)+1, pss_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pss_var, "valid_range", NC_FLOAT, 2, pss_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pss_var, "missing_value", NC_FLOAT, 1, &pss_missing_value)) ERR(retval);
  }

  /* SSM/I scattering precipitation number of samples */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "nss", NC_FLOAT, 2, std_dims, &nss_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nss_var, "long_name", strlen(nss_longname)+1, nss_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nss_var, "units", strlen(nss_units)+1, nss_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nss_var, "coordinates", strlen(nss_coordinates)+1, nss_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nss_var, "valid_range", NC_FLOAT, 2, nss_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nss_var, "missing_value", NC_FLOAT, 1, &nss_missing_value)) ERR(retval);
  }

  /* SSM/I composite precipitation estimate */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "psc", NC_FLOAT, 2, std_dims, &psc_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psc_var, "long_name", strlen(psc_longname)+1, psc_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psc_var, "units", strlen(psc_units)+1, psc_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, psc_var, "coordinates", strlen(psc_coordinates)+1, psc_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, psc_var, "valid_range", NC_FLOAT, 2, psc_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, psc_var, "missing_value", NC_FLOAT, 1, &psc_missing_value)) ERR(retval);
  }

  /* SSM/I composite precipitation source */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "ssc", NC_FLOAT, 2, std_dims, &ssc_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ssc_var, "long_name", strlen(ssc_longname)+1, ssc_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ssc_var, "units", strlen(ssc_units)+1, ssc_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ssc_var, "coordinates", strlen(ssc_coordinates)+1, ssc_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ssc_var, "valid_range", NC_FLOAT, 2, ssc_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ssc_var, "missing_value", NC_FLOAT, 1, &ssc_missing_value)) ERR(retval);
  }

  /* SSM/I composite precipitation number of samples */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "nsc", NC_FLOAT, 2, std_dims, &nsc_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nsc_var, "long_name", strlen(nsc_longname)+1, nsc_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nsc_var, "units", strlen(nsc_units)+1, nsc_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, nsc_var, "coordinates", strlen(nsc_coordinates)+1, nsc_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nsc_var, "valid_range", NC_FLOAT, 2, nsc_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, nsc_var, "missing_value", NC_FLOAT, 1, &nsc_missing_value)) ERR(retval);
  }

  /* Merged SSMI/TOVS precipitation estimate */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "pst", NC_FLOAT, 2, std_dims, &pst_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pst_var, "long_name", strlen(pst_longname)+1, pst_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pst_var, "units", strlen(pst_units)+1, pst_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, pst_var, "coordinates", strlen(pst_coordinates)+1, pst_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pst_var, "valid_range", NC_FLOAT, 2, pst_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, pst_var, "missing_value", NC_FLOAT, 1, &pst_missing_value)) ERR(retval);
  }

  /* Merged SSMI/TOVS precipitation random error */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "est", NC_FLOAT, 2, std_dims, &est_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, est_var, "long_name", strlen(est_longname)+1, est_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, est_var, "units", strlen(est_units)+1, est_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, est_var, "coordinates", strlen(est_coordinates)+1, est_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, est_var, "valid_range", NC_FLOAT, 2, est_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, est_var, "missing_value", NC_FLOAT, 1, &est_missing_value)) ERR(retval);
  }

  /* Merged SSMI/TOVS precipitation source */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "sst", NC_FLOAT, 2, std_dims, &sst_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, sst_var, "long_name", strlen(sst_longname)+1, sst_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, sst_var, "units", strlen(sst_units)+1, sst_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, sst_var, "coordinates", strlen(sst_coordinates)+1, sst_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, sst_var, "valid_range", NC_FLOAT, 2, sst_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, sst_var, "missing_value", NC_FLOAT, 1, &sst_missing_value)) ERR(retval);
  }

  /* TOVS precipitation estimate */
  if (oflag==3) {
    if (retval = nc_def_var(ncid, "ptv", NC_FLOAT, 2, std_dims, &ptv_var)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ptv_var, "long_name", strlen(ptv_longname)+1, ptv_longname)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ptv_var, "units", strlen(ptv_units)+1, ptv_units)) ERR(retval);
    if (retval = nc_put_att_text(ncid, ptv_var, "coordinates", strlen(ptv_coordinates)+1, ptv_coordinates)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ptv_var, "valid_range", NC_FLOAT, 2, ptv_valid_range)) ERR(retval);
    if (retval = nc_put_att_float(ncid, ptv_var, "missing_value", NC_FLOAT, 1, &ptv_missing_value)) ERR(retval);
  }





  /*********************************************************
   * End define mode: start writing data                   *
   *********************************************************/
  if (retval = nc_enddef(ncid)) ERR(retval);


  // Define latitudes and write to file
  for (i=0; i<72; i++) {
    lat_values[i]=-90.+(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, latitude_var, &lat_values[0])) ERR(retval);
  
  // Define longitudes and write to file
  for (i=0; i<144; i++) {
    lon_values[i]=(float)i*2.5;
  }
  if (retval = nc_put_var_float(ncid, longitude_var, &lon_values[0])) ERR(retval);

  // Read OLR and and add to netcdf file
  if (oflag==1) {
    sprintf(fname_pop,"%s/bin/%04d/%02d/oc.%04d%02d.adge",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pop=fopen(fname_pop,"r");
    if (fp_pop == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pop);
      exit(EXIT_FAILURE);
    }
    fread(&pop_values[0][0], sizeof(pop_values), 144*72, fp_pop);
    fclose(fp_pop);
    if (retval = nc_put_var_float(ncid, pop_var, &pop_values[0][0])) ERR(retval);
  }

  // Read Multi-satellite and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_pms,"%s/bin/%04d/%02d/oc.%04d%02d.s",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pms=fopen(fname_pms,"r");
    if (fp_pms == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pms);
      exit(EXIT_FAILURE);
    }
    fread(&pms_values[0][0], sizeof(pms_values), 144*72, fp_pms);
    fclose(fp_pms);
    if (retval = nc_put_var_float(ncid, pms_var, &pms_values[0][0])) ERR(retval);
  }

  // Read Gauge precipitation and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_pga,"%s/bin/%04d/%02d/oc.%04d%02d.corg",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pga=fopen(fname_pga,"r");
    if (fp_pga == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pga);
      exit(EXIT_FAILURE);
    }
    fread(&pga_values[0][0], sizeof(pga_values), 144*72, fp_pga);
    fclose(fp_pga);
    if (retval = nc_put_var_float(ncid, pga_var, &pga_values[0][0])) ERR(retval);
  }

  // Read Satellite/gauge precipitation and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_psg,"%s/bin/%04d/%02d/oc.%04d%02d.sg",OutputPATH,yyyy,mm,yyyy,mm);
    fp_psg=fopen(fname_psg,"r");
    if (fp_psg == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_psg);
      exit(EXIT_FAILURE);
    }
    fread(&psg_values[0][0], sizeof(psg_values), 144*72, fp_psg);
    fclose(fp_psg);
    if (retval = nc_put_var_float(ncid, psg_var, &psg_values[0][0])) ERR(retval);
  }

  // Read OLR and and add to netcdf file
  if (oflag==1) {
    sprintf(fname_eop,"%s/bin/%04d/%02d/oc.%04d%02d.egeo",OutputPATH,yyyy,mm,yyyy,mm);
    fp_eop=fopen(fname_eop,"r");
    if (fp_eop == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_eop);
      exit(EXIT_FAILURE);
    }
    fread(&eop_values[0][0], sizeof(eop_values), 144*72, fp_eop);
    fclose(fp_eop);
    if (retval = nc_put_var_float(ncid, eop_var, &eop_values[0][0])) ERR(retval);
  }

  // Read data and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_ems,"%s/bin/%04d/%02d/oc.%04d%02d.es",OutputPATH,yyyy,mm,yyyy,mm);
    fp_ems=fopen(fname_ems,"r");
    if (fp_ems == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_ems);
      exit(EXIT_FAILURE);
    }
    fread(&ems_values[0][0], sizeof(ems_values), 144*72, fp_ems);
    fclose(fp_ems);
    if (retval = nc_put_var_float(ncid, ems_var, &ems_values[0][0])) ERR(retval);
  }

  // Read Gauge precipitation random error and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_ega,"%s/bin/%04d/%02d/oc.%04d%02d.ega",OutputPATH,yyyy,mm,yyyy,mm);
    fp_ega=fopen(fname_ega,"r");
    if (fp_ega == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_ega);
      exit(EXIT_FAILURE);
    }
    fread(&ega_values[0][0], sizeof(ega_values), 144*72, fp_ega);
    fclose(fp_ega);
    if (retval = nc_put_var_float(ncid, ega_var, &ega_values[0][0])) ERR(retval);
  }

  // Read Satellite/gauge precipitation random error and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_esg,"%s/bin/%04d/%02d/oc.%04d%02d.esg",OutputPATH,yyyy,mm,yyyy,mm);
    fp_esg=fopen(fname_esg,"r");
    if (fp_esg == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_esg);
      exit(EXIT_FAILURE);
    }
    fread(&esg_values[0][0], sizeof(esg_values), 144*72, fp_esg);
    fclose(fp_esg);
    if (retval = nc_put_var_float(ncid, esg_var, &esg_values[0][0])) ERR(retval);
  }

  // Read Gauge precipitation number of gauges and and add to netcdf file
  if (oflag==1 | oflag==2 | oflag==3) {
    sprintf(fname_nga,"%s/bin/%04d/%02d/oc.%04d%02d.nga",OutputPATH,yyyy,mm,yyyy,mm);
    fp_nga=fopen(fname_nga,"r");
    if (fp_nga == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_nga);
      exit(EXIT_FAILURE);
    }
    fread(&nga_values[0][0], sizeof(nga_values), 144*72, fp_nga);
    fclose(fp_nga);
    if (retval = nc_put_var_float(ncid, nga_var, &nga_values[0][0])) ERR(retval);
  }

  // Read Adjusted GOES Precipitation Index (AGPI) precipitation estimate and and add to netcdf file
  if (oflag==2 | oflag==3) {
    sprintf(fname_pag,"%s/bin/%04d/%02d/oc.%04d%02d.adge",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pag=fopen(fname_pag,"r");
    if (fp_pag == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pag);
      exit(EXIT_FAILURE);
    }
    fread(&pag_values[0][0], sizeof(pag_values), 144*72, fp_pag);
    fclose(fp_pag);
    if (retval = nc_put_var_float(ncid, pag_var, &pag_values[0][0])) ERR(retval);
  }

  // Read Adjusted GOES Precipitation Index (AGPI) precipitation random error and and add to netcdf file
  if (oflag==2 | oflag==3) {
    sprintf(fname_eag,"%s/bin/%04d/%02d/oc.%04d%02d.egeo",OutputPATH,yyyy,mm,yyyy,mm);
    fp_eag=fopen(fname_eag,"r");
    if (fp_eag == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_eag);
      exit(EXIT_FAILURE);
    }
    fread(&eag_values[0][0], sizeof(eag_values), 144*72, fp_eag);
    fclose(fp_eag);
    if (retval = nc_put_var_float(ncid, eag_var, &eag_values[0][0])) ERR(retval);
  }

  // Read Outgoing Longwave Radiation (OLR) Precipitation Index (OPI) precipitation estimate and and add to netcdf file
  if (oflag==2) {
    sprintf(fname_pop,"%s/bin/%04d/%02d/opi.%04d%02d.rssfix",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pop=fopen(fname_pop,"r");
    if (fp_pop == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pop);
      exit(EXIT_FAILURE);
    }
    fread(&pop_values[0][0], sizeof(pop_values), 144*72, fp_pop);
    fclose(fp_pop);
    if (retval = nc_put_var_float(ncid, pop_var, &pop_values[0][0])) ERR(retval);
  }

  // Read GOES Precipitation Index (GPI) precipitation estimate and and add to netcdf file
  if (oflag==2 | oflag==3) {
    sprintf(fname_pgp,"%s/bin/%04d/%02d/oc.%04d%02d.pgp",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pgp=fopen(fname_pgp,"r");
    if (fp_pgp == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pgp);
      exit(EXIT_FAILURE);
    }
    fread(&pgp_values[0][0], sizeof(pgp_values), 144*72, fp_pgp);
    fclose(fp_pgp);
    if (retval = nc_put_var_float(ncid, pgp_var, &pgp_values[0][0])) ERR(retval);
  }

  // Read GOES Precipitation Index (GPI) image number and and add to netcdf file
  if (oflag==2 | oflag==3) {
    sprintf(fname_ngp,"%s/bin/%04d/%02d/oc.%04d%02d.ngp",OutputPATH,yyyy,mm,yyyy,mm);
    fp_ngp=fopen(fname_ngp,"r");
    if (fp_ngp == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_ngp);
      exit(EXIT_FAILURE);
    }
    fread(&ngp_values[0][0], sizeof(ngp_values), 144*72, fp_ngp);
    fclose(fp_ngp);
    if (retval = nc_put_var_float(ncid, ngp_var, &ngp_values[0][0])) ERR(retval);
  }

  // Read SSM/I emission precipitation estimate and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_pse,"%s/bin/%04d/%02d/cg.%04d%02d.rcfull",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pse=fopen(fname_pse,"r");
    if (fp_pse == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pse);
      exit(EXIT_FAILURE);
    }
    fread(&pse_values[0][0], sizeof(pse_values), 144*72, fp_pse);
    fclose(fp_pse);
    if (retval = nc_put_var_float(ncid, pse_var, &pse_values[0][0])) ERR(retval);
  }

  // Read SSM/I emission precipitation number of samples and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_nse,"%s/bin/%04d/%02d/cg.%04d%02d.Icfull",OutputPATH,yyyy,mm,yyyy,mm);
    fp_nse=fopen(fname_nse,"r");
    if (fp_nse == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_nse);
      exit(EXIT_FAILURE);
    }
    fread(&nse_values[0][0], sizeof(nse_values), 144*72, fp_nse);
    fclose(fp_nse);
    if (retval = nc_put_var_float(ncid, nse_var, &nse_values[0][0])) ERR(retval);
  }

  // Read SSM/I scattering precipitation estimate and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_pss,"%s/bin/%04d/%02d/cg.%04d%02d.rgfull",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pss=fopen(fname_pss,"r");
    if (fp_pss == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pss);
      exit(EXIT_FAILURE);
    }
    fread(&pss_values[0][0], sizeof(pss_values), 144*72, fp_pss);
    fclose(fp_pss);
    if (retval = nc_put_var_float(ncid, pss_var, &pss_values[0][0])) ERR(retval);
  }

  // Read SSM/I scattering precipitation number of samples and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_nss,"%s/bin/%04d/%02d/cg.%04d%02d.Igfull",OutputPATH,yyyy,mm,yyyy,mm);
    fp_nss=fopen(fname_nss,"r");
    if (fp_nss == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_nss);
      exit(EXIT_FAILURE);
    }
    fread(&nss_values[0][0], sizeof(nss_values), 144*72, fp_nss);
    fclose(fp_nss);
    if (retval = nc_put_var_float(ncid, nss_var, &nss_values[0][0])) ERR(retval);
  }

  // Read SSM/I composite precipitation estimate and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_psc,"%s/bin/%04d/%02d/cg.%04d%02d.rfix",OutputPATH,yyyy,mm,yyyy,mm);
    fp_psc=fopen(fname_psc,"r");
    if (fp_psc == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_psc);
      exit(EXIT_FAILURE);
    }
    fread(&psc_values[0][0], sizeof(psc_values), 144*72, fp_psc);
    fclose(fp_psc);
    if (retval = nc_put_var_float(ncid, psc_var, &psc_values[0][0])) ERR(retval);
  }

  // Read SSM/I composite precipitation source and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_ssc,"%s/bin/%04d/%02d/cg.%04d%02d.src",OutputPATH,yyyy,mm,yyyy,mm);
    fp_ssc=fopen(fname_ssc,"r");
    if (fp_ssc == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_ssc);
      exit(EXIT_FAILURE);
    }
    fread(&ssc_values[0][0], sizeof(ssc_values), 144*72, fp_ssc);
    fclose(fp_ssc);
    if (retval = nc_put_var_float(ncid, ssc_var, &ssc_values[0][0])) ERR(retval);
  }

  // Read SSM/I composite precipitation number of samples and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_nsc,"%s/bin/%04d/%02d/cg.%04d%02d.Ifix",OutputPATH,yyyy,mm,yyyy,mm);
    fp_nsc=fopen(fname_nsc,"r");
    if (fp_nsc == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_nsc);
      exit(EXIT_FAILURE);
    }
    fread(&nsc_values[0][0], sizeof(nsc_values), 144*72, fp_nsc);
    fclose(fp_nsc);
    if (retval = nc_put_var_float(ncid, nsc_var, &nsc_values[0][0])) ERR(retval);
  }

  // Read Merged SSMI/TOVS precipitation estimate and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_pst,"%s/bin/%04d/%02d/cg.%04d%02d.rfix",OutputPATH,yyyy,mm,yyyy,mm);
    fp_pst=fopen(fname_pst,"r");
    if (fp_pst == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_pst);
      exit(EXIT_FAILURE);
    }
    fread(&pst_values[0][0], sizeof(pst_values), 144*72, fp_pst);
    fclose(fp_pst);
    if (retval = nc_put_var_float(ncid, pst_var, &pst_values[0][0])) ERR(retval);
  }

  // Read Merged SSMI/TOVS precipitation random error and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_est,"%s/bin/%04d/%02d/oc.%04d%02d.ess",OutputPATH,yyyy,mm,yyyy,mm);
    fp_est=fopen(fname_est,"r");
    if (fp_est == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_est);
      exit(EXIT_FAILURE);
    }
    fread(&est_values[0][0], sizeof(est_values), 144*72, fp_est);
    fclose(fp_est);
    if (retval = nc_put_var_float(ncid, est_var, &est_values[0][0])) ERR(retval);
  }

  if (oflag==3) {
  // Read Merged SSMI/TOVS precipitation source and and add to netcdf file
    sprintf(fname_sst,"%s/bin/%04d/%02d/cgt.%04d%02d.src",OutputPATH,yyyy,mm,yyyy,mm);
    fp_sst=fopen(fname_sst,"r");
    if (fp_sst == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_sst);
      exit(EXIT_FAILURE);
    }
    fread(&sst_values[0][0], sizeof(sst_values), 144*72, fp_sst);
    fclose(fp_sst);
    if (retval = nc_put_var_float(ncid, sst_var, &sst_values[0][0])) ERR(retval);
  }

  // Read TOVS precipitation estimate and and add to netcdf file
  if (oflag==3) {
    sprintf(fname_ptv,"%s/bin/%04d/%02d/cgt.%04d%02d.tovs",OutputPATH,yyyy,mm,yyyy,mm);
    fp_ptv=fopen(fname_ptv,"r");
    if (fp_ptv == NULL) {
      fprintf(stderr,"Can't open file: %s\n",fname_ptv);
      exit(EXIT_FAILURE);
    }
    fread(&ptv_values[0][0], sizeof(ptv_values), 144*72, fp_ptv);
    fclose(fp_ptv);
    if (retval = nc_put_var_float(ncid, ptv_var, &ptv_values[0][0])) ERR(retval);
  }




  /* Close netcdf file */
  if ((retval = nc_close(ncid))) ERR(retval);


}
